package com.uas.b2c.pay.api;

import com.uas.b2c.pay.assistant.ResultMap;
import com.uas.b2c.pay.service.KHUnionPayQuikService;
import org.apache.log4j.LogManager;
import org.apache.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.HashMap;

/**
 * 银联快捷支付接口
 *
 * @author yuj 2017-12-21 14:59
 */
@RestController
@RequestMapping("/UnionPay")
public class KHUnionPayQuikController {

    private final Logger logger = LogManager.getLogger(getClass());

    private final KHUnionPayQuikService kHUnionPayQuikService;

    @Autowired
    public KHUnionPayQuikController(KHUnionPayQuikService kHUnionPayQuikService) {
        this.kHUnionPayQuikService = kHUnionPayQuikService;
    }

    /**
     * 快捷支付银联绑卡的功能
     *
     * @param map 传入的参数
     *
     * @return map 包含签名、返回地址等
     */
    @PostMapping(value = "/bindCard", produces = "application/json")
    public ResultMap bindCard(@RequestBody HashMap<String, String> map) {
        logger.assertLog(true, "银联快捷支付的绑卡动作");
        return kHUnionPayQuikService.kHBindCard(map);
    }

    /**
     *  根据个人信息查询绑卡信息
     *
     * @param map 用户的信息
     * @return 返回用户的绑定卡的信息
     */
    @PostMapping(value = "/bindCard/query", produces = "application/json")
    public ResultMap queryBindCards(@RequestBody HashMap<String, String> map) {
        logger.assertLog(true, "银联快捷支付的绑卡动作");
        return kHUnionPayQuikService.queryBindCards(map);
    }


    /**
     * 快捷支付的短信接口
     *
     * @param map 包含的支付信息
     * @return String 返回的信息
     */
    @PostMapping(value = "/sms", produces = "application/json")
    public String khPaySMS(@RequestBody HashMap<String, String> map) {
        logger.assertLog(true, "银联快捷支付的绑卡动作");
        return kHUnionPayQuikService.khPaySMS(map);
    }


    /**
     * 银联的支付动作接口
     *
     * @param map 传入的数据
     *            orderId  订单流水号
     *            currency 支付的币别信息
     *            amount 订单金额
     *            objectName 订单款项描述
     *            paydate 下单时间
     *            validtime 订单有效期(毫秒)，0不生效
     *            NOTIFYURL 后台通知地址
     *            remark 备注字段，具体看具体看remark字段的数据组装.txt 否
     *            verifyCode 短信的验证码
     *            subcstno 二级商户号 否
     *            OpenId 同customerId
     *            payType 03：银联快捷
     *            issInsCode 发卡机构代码
     *            payCardType 支付卡类型，01：借记卡，02：信用卡 否
     *            orderType 订单类型，用于区分T0、T1交易。只在开通了T0清算的时候起作用，默认T1清算 否
     * @return 结果json 字符串
     */
    @PostMapping(value = "/pay", produces = "application/json")
    public ResultMap khPay(@RequestBody HashMap<String, String> map) {
        logger.assertLog(true, "银联快捷支付的绑卡动作");
        return kHUnionPayQuikService.khPay(map);
    }

}
