package com.uas.b2c.pay.api;

import com.uas.b2c.pay.assistant.ResultMap;
import com.uas.b2c.pay.service.AssociatorSubAccountService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.HashMap;

/**
 * 平安开户的接口
 *
 * @author yuj 2017-11-20 11:27
 */
@RestController
@RequestMapping(value = "/pingan/account")
public class PingAnAccountController {

    private final AssociatorSubAccountService associatorSubAccountService;

    @Autowired
    public PingAnAccountController(AssociatorSubAccountService associatorSubAccountService) {
        this.associatorSubAccountService = associatorSubAccountService;
    }

    /**
     * 会员开户
     * @param map 传入的数据
     * @return
     */
    @PostMapping(value = "/openAccount")
    public ResultMap openAccount(@RequestBody HashMap<String, String> map) {
        ResultMap resultMap = associatorSubAccountService.openSubAccount(map);
        return resultMap;
    }


    /**
     * 获取资金汇总账户的信息
     * @return
     */
    @PostMapping(value = "/base/account")
    public String getBaseAccountInfo() {
        String info = associatorSubAccountService.getBaseAccountInfo();
        return info;
    }

    /**
     * 获取子账户信息
     *
     * @param map 传入的信息
     * @return
     */
    @PostMapping(value = "/subAccountInfo")
    public String getSubAccountInfo(@RequestBody HashMap<String, String> map)  {
//        HashMap map = new HashMap();
//        map.put(PingAnField.CUSTACCTID, "3239000000006038");
//        map.put(PingAnField.SELECTFLAG, PingAnEnum.SELECT_FLAG_COMMON.getTag());
//        map.put(PingAnField.PAGENUM, StringConstant.MIN_POSITIVE_INTEGER);
//        map.put(PingAnField.RESERVE, StringConstant.EMPTY_STR);
//        map.put(B2CField.USERUU, "1000103422");
        associatorSubAccountService.getSubAccountInfo(map);
        return "ok";
    }

    /**
     * 查询银行在途清算结果【6108】
     *
     * @param map 传入的数据
     * @return
     */
    @PostMapping(value = "/query/settleAccounts")
    public String querySettleAccounts(@RequestBody HashMap<String, String> map) {
        return associatorSubAccountService.querySettleAccounts(map);
    }


    /**
     * 查询子帐号历史余额及待转可提现状态信息【6114】
     *
     * @param map 传入的信息
     * @return String
     */
    @PostMapping(value = "/query/histRemainderWithDrawInfo")
    public String querySubAccountHistoryRemainderAndCanWithDrawInfo(@RequestBody HashMap<String, String> map) {
        return associatorSubAccountService.querySubAccountHistoryRemainderAndCanWithDrawInfo(map);
    }


    /**
     * 查询银行时间段内清分提现明细【6073】
     *
     * @param map 传入的数据
     * @return
     */
    @PostMapping(value = "/query/distribution/withDraw")
    public String queryDistributionAndWithDrawDetail(@RequestBody HashMap<String, String> map) {
        return associatorSubAccountService.queryDistributionAndWithDrawDetail(map);
    }

    /**
     * 根据会员代码查询会员子账号【6092】
     *
     * @param map 传入的信息
     * @return String
     */
    @PostMapping(value = "/query/account")
    public String queryAccountInfo(@RequestBody HashMap<String, String> map) {
        return associatorSubAccountService.queryAccountInfo(map);
    }

    /**
     * 查询对账文件信息【6103】（余额，充值，体现，交易）
     *
     * @param map 传入的数据
     * @return String
     */
    @PostMapping(value = "/query/accountStatement")
    public String queryAccountStatement(@RequestBody HashMap<String, String> map) {
        return associatorSubAccountService.queryAccountStatement(map);
    }
}
