package com.uas.b2c.pay.api;

import com.uas.b2c.pay.assistant.ResultMap;
import com.uas.b2c.pay.service.AssociatorSubAccountService;
import com.uas.b2c.pay.service.AssociatorTradeService;
import com.uas.b2c.pay.util.FastjsonUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import java.util.HashMap;

/**
 *  关于交易类的接口
 *
 * @author yuj 2017-11-20 10:37
 */
@RestController
@RequestMapping(value = "/pingan/trade")
public class PingAnTradeController {

    private final AssociatorTradeService associatorTradeService;

    private final AssociatorSubAccountService associatorSubAccountService;

    @Autowired
    public PingAnTradeController(AssociatorTradeService associatorTradeService, AssociatorSubAccountService associatorSubAccountService) {
        this.associatorTradeService = associatorTradeService;
        this.associatorSubAccountService = associatorSubAccountService;
    }

    /**44444444444444444444信息不全
     * 会员间交易（验证短信动态码）【6101】
     *
     * @param map
     * @return
     */
    @RequestMapping(value = "pay", method = RequestMethod.POST)
    public String pay(@RequestBody HashMap<String, String> map) {
        return associatorTradeService.payOrRefund(map).getMessage();
    }


    /**
     * 会员充值(在途)【6056】
     *
     * @param map 传入的数据
     * @return String
     */
    @PostMapping(value = "/recharge")
    public String rechargeMember(@RequestBody HashMap<String, String> map) {
        return associatorTradeService.rechargeMember(map);
    }

    /**8888888888888888888888888888
     * 会员提现（验证短信验证码）【6085】
     *
     * @param map 传入的数据
     * @return String
     */
    @PostMapping(value = "/withdrawCash/verification")
    public String withdrawCashVerification(@RequestBody HashMap<String, String> map)  {
        return associatorTradeService.withdrawCashVerification(map);
    }


    /**88888888888888888
     * 申请提现或支付短信动态码【6082】
     * @param map 传入的数据
     * @return String
     */
    @PostMapping(value = "/getSMSVerification")
    public String getSMSVerification(@RequestBody HashMap<String, String> map)  {
        ResultMap smsVerification = associatorTradeService.getSMSVerification(map);
        return FastjsonUtils.toJson(smsVerification);
    }


    /**要6135接口测试了才可以测;
     * 交易撤销【6077】
     *
     * @param map
     * @return
     */
    @PostMapping(value = "/expenditure/apply")
    public String expenditureApply(HashMap<String, String> map) {
        return associatorTradeService.expenditureApply(map);
    }

    /**这个接口已经有了
     * 申请提现或支付短信动态码【6082】
     *
     * @param map 传入的数据
     * @return String
     *//*
    @PostMapping(value = "/calloff")
    public String tradeCallOff(HashMap<String, String> map) {
        return associatorTradeService.tradeCallOff(map);
    }
*/
    /**
     * 查询银行子账户余额【6010】
     *
     * @param map 传入的数据
     * @return
     */
    @PostMapping(value = "/settleAccount/query")
    public String querySettleAccounts(@RequestBody HashMap<String, String> map) {
        return associatorTradeService.querySettleAccounts(map);
    }

    /**
     * 查询银行单笔交易状态(6094优化版)【6110】
     *
     * @param map 传入的时间
     * @return String
     */
    @PostMapping(value = "/query/order/status")
    public String orderTradeStatus(@RequestBody HashMap<String, String> map) {
        return associatorTradeService.orderTradeStatus(map);
    }


    /**
     * 查询银行提现退单信息【6048】
     * @param map 传入的数据
     * @return
     */
    @PostMapping(value = "/withDrawChargeBack")
    public String queryWithdrawChargeBack(@RequestBody HashMap<String, String> map) {
        return associatorTradeService.queryWithdrawChargeBack(map);
    }


    /**
     *查询普通转账充值明细【6050】
     *
     * @param map 传入的数据
     * @return String
     */
    @PostMapping(value = "/query/transferDetail")
    public String queryTransferAccountsDetail(@RequestBody HashMap<String, String> map) {
        return associatorTradeService.queryTransferAccountsDetail(map);
    }

    /**
     * 查询银行时间段内交易明细【6072】
     *
     * @param map 输入的信息
     * @return String
     */
    @PostMapping(value = "/query/trade")
    public String queryAccountTradeInfo(@RequestBody HashMap<String, String> map) {
        return associatorTradeService.queryAccountTradeInfo(map);
    }

    /**
     * 登记挂账【6008】（挂账子账户中余额转到对应的子账户)
     *
     * @param map
     * @return
     */
    @PostMapping(value = "/distributionSpecialAccount")
    public String distributionSpecialAccount(@RequestBody HashMap<String, String> map) {
        return associatorTradeService.distributionSpecialAccount(map);
    }

    /**8888888888888888888888888888888888
     * 查询充值明细（见证+收单）【6146】
     *
     * @param map 传入的订单号
     * @return String
     */
    @PostMapping(value = "/query/rechargeDetail")
    public String queryRechargeDetail(@RequestBody HashMap<String, String> map) {
        return associatorTradeService.queryRechargeDetail(map);
    }

    /**
     * 调账(见证+收单)【6145】
     *
     * @param map
     * @return
     */
    @PostMapping(value = "/adjustAccount")
    public String adjustAccount(@RequestBody HashMap<String, String> map) {
        return associatorTradeService.adjustAccount(map);
    }


    /**
     * 平台补账(见证+收单)【6147】
     *
     * @param map
     * @return
     */
    @PostMapping(value = "/makeUpAccount")
    public String makeUpAccount(@RequestBody HashMap<String, String> map) {
        return associatorTradeService.makeUpAccount(map);
    }



}
