package com.uas.b2c.pay.domain;

import com.uas.b2c.pay.constant.B2CField;
import com.uas.b2c.pay.constant.PingAnField;
import org.apache.commons.collections.MapUtils;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;
import java.util.HashMap;

/**
 * 子账户 我们称为 SubAccounnt 也包含（AssociatorSubAccount）
 * 资金汇总账户我们称为 BaseAccount
 *
 * @author yuj 2017-11-09 16:33
 */
@Entity
@Table(name = "bank$associatorsubaccount")
public class AssociatorSubAccount implements Serializable{

    private static final long serialVersionUID = -8710436068906282626L;

    @Id
    @Column(name = "id")
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    private Long id;

    /**
     * 个人uu
     */
    @Column(name = "basb_useruu")
    private Long useruu;

    /**
     * 企业的uu
     */
    @Column(name = "basb_enuu")
    private Long enuu;


    /**
     * 是个人用户还是企业用户
     */
    @Column(name = "basb_ispersonal")
    private Boolean isPersonal;

    /**
     * 个人用户是否是游离的（个人用户）还是关联帐套
     */
    @Column(name = "basb_dissociative")
    private Boolean dissociative;

    /**
     * 会员子账户的id信息
     */
    @Column(name = "basb_subaccountid")
    private String subAccountid;

    /**
     * 账户创建时间
     */
    @Column(name = "basb_createtime")
    private Date createTime;

    /**
     * 传给平安的会员id信息(主要由useruu和enuu 信息组成)
     */
    @Column(name = "basb_pinganthirdid")
    private String pingAnThirdId;

    /**
     * 手机号
     */
    @Column(name = "basb_telephone")
    private String telephone;

    /**
     * 别名
     */
    @Column(name = "basb_nickname")
    private String nickName;

    /**
     * 邮箱
     */
    @Column(name = "basb_email")
    private String email;

    /**
     * 会员的属性
     */
    @Column(name = "basb_accountproperty")
    private String accountProperty;


    public Long getId() {
        return id;
    }

    public AssociatorSubAccount setId(Long id) {
        this.id = id;
        return this;
    }

    public Long getUseruu() {
        return useruu;
    }

    public AssociatorSubAccount setUseruu(Long useruu) {
        this.useruu = useruu;
        return this;
    }

    public Long getEnuu() {
        return enuu;
    }

    public AssociatorSubAccount setEnuu(Long enuu) {
        this.enuu = enuu;
        return this;
    }

    public Boolean getPersonal() {
        return isPersonal;
    }

    public AssociatorSubAccount setPersonal(Boolean personal) {
        isPersonal = personal;
        return this;
    }

    public Boolean getDissociative() {
        return dissociative;
    }

    public AssociatorSubAccount setDissociative(Boolean dissociative) {
        this.dissociative = dissociative;
        return this;
    }

    public String getSubAccountid() {
        return subAccountid;
    }

    public AssociatorSubAccount setSubAccountid(String subAccountid) {
        this.subAccountid = subAccountid;
        return this;
    }

    public Date getCreateTime() {
        return createTime;
    }

    public AssociatorSubAccount setCreateTime(Date createTime) {
        this.createTime = createTime;
        return this;
    }

    public String getPingAnThirdId() {
        return pingAnThirdId;
    }

    public AssociatorSubAccount setPingAnThirdId(String pingAnThirdId) {
        this.pingAnThirdId = pingAnThirdId;
        return this;
    }

    public AssociatorSubAccount() {
    }

    public String getTelephone() {
        return telephone;
    }

    public AssociatorSubAccount setTelephone(String telephone) {
        this.telephone = telephone;
        return this;
    }

    public String getNickName() {
        return nickName;
    }

    public AssociatorSubAccount setNickName(String nickName) {
        this.nickName = nickName;
        return this;
    }

    public String getEmail() {
        return email;
    }

    public AssociatorSubAccount setEmail(String email) {
        this.email = email;
        return this;
    }

    public AssociatorSubAccount(Long useruu, Long enuu, Boolean isPersonal, Boolean dissociative, String subAccountid,
                                Date createTime, String pingAnThirdId, String telephone, String nickName, String email, String accountProperty) {
        this.useruu = useruu;
        this.enuu = enuu;
        this.isPersonal = isPersonal;
        this.dissociative = dissociative;
        this.subAccountid = subAccountid;
        this.createTime = createTime;
        this.pingAnThirdId = pingAnThirdId;
        this.telephone = telephone;
        this.nickName = nickName;
        this.email = email;
        this.accountProperty = accountProperty;
    }

    /**
     *
     */
    public static AssociatorSubAccount createAssociatorSubAccount(HashMap<String, String> map, HashMap retKeyDict, HashMap<String, String> parmaKeyDict) {
        if (MapUtils.isEmpty(map)) {
            return null;
        }
        Long useruu = null;
        Boolean isPersonal = null;
        Boolean dissociative = null;
        Long enuu = null;
        try {
            isPersonal = Boolean.valueOf(map.get(B2CField.ISPERSONAL));
            dissociative = Boolean.valueOf(map.get(B2CField.DISSOCIATIVE));
            if (!dissociative) {
                enuu = Long.valueOf(map.get(B2CField.ENUU));
            }
            if (isPersonal) {
                useruu = Long.valueOf(map.get(B2CField.USERUU));
            }
        } catch (Exception e) {
            throw new IllegalArgumentException("传入的用户信息错误");
        }

        String subAccountid = (String) retKeyDict.get(PingAnField.CUSTACCTID);
        Date createTime = new Date();
        String pingAnThirdId = parmaKeyDict.get(PingAnField.THIRDCUSTID);
        String telephone = parmaKeyDict.get(PingAnField.MOBILEPHONE);
        String nickName = parmaKeyDict.get(PingAnField.NICKNAME);
        String email = parmaKeyDict.get(PingAnField.EMAIL);
        String accountProperty = parmaKeyDict.get(PingAnField.CUSTPROPERTY);
        AssociatorSubAccount sub = new AssociatorSubAccount(useruu, enuu, isPersonal, dissociative,
                subAccountid, createTime, pingAnThirdId, telephone, nickName, email, accountProperty);
        return sub;
    }

    public String getAccountProperty() {
        return accountProperty;
    }

    public AssociatorSubAccount setAccountProperty(String accountProperty) {
        this.accountProperty = accountProperty;
        return this;
    }
}
