package com.uas.b2c.pay.domain;

import com.uas.b2c.pay.constant.KHField;
import com.uas.b2c.pay.constant.RechargeEnum;
import com.uas.b2c.pay.util.AssistantUtil;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;
import java.util.HashMap;

/**
 *  收单系统的充值记录
 *
 * @author yuj 2018-01-17 20:08
 */
@Entity
@Table(name = "bank$receiptsrechargerecord")
public class ReceiptsRechargeRecord implements Serializable{

    private static final long serialVersionUID = 5623546820889767946L;

    @Id
    @Column(name = "recharge_id")
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    private Long id;

    /**
     * 充值的时间
     */
    @Column(name = "recharge_createtime")
    private Date chargeTime;

    /**
     * 充值的流水号
     */
    @Column(name = "recharge_serialnumber")
    private String serialNumber;


    /**
     * 充值的金额
     */
    @Column(name = "recharge_amount")
    private Double amount;

    /**
     * 支付的方式
     */
    @Column(name = "recharge_paytype")
    private String payType;

    /**
     * 状态
     */
    @Column(name = "recharge_status")
    private Integer status;

    /**
     * 传给平安的会员id信息(主要由useruu和enuu 信息组成)
     */
    @Column(name = "recharge_pinganthirdid")
    private String pingAnThirdId;


    public Long getId() {
        return id;
    }

    public ReceiptsRechargeRecord setId(Long id) {
        this.id = id;
        return this;
    }

    public Date getChargeTime() {
        return chargeTime;
    }

    public ReceiptsRechargeRecord setChargeTime(Date chargeTime) {
        this.chargeTime = chargeTime;
        return this;
    }

    public String getSerialNumber() {
        return serialNumber;
    }

    public ReceiptsRechargeRecord setSerialNumber(String serialNumber) {
        this.serialNumber = serialNumber;
        return this;
    }

    public Double getAmount() {
        return amount;
    }

    public ReceiptsRechargeRecord setAmount(Double amount) {
        this.amount = amount;
        return this;
    }

    public String getPayType() {
        return payType;
    }

    public ReceiptsRechargeRecord setPayType(String payType) {
        this.payType = payType;
        return this;
    }

    public Integer getStatus() {
        return status;
    }

    public ReceiptsRechargeRecord setStatus(Integer status) {
        this.status = status;
        return this;
    }

    public String getPingAnThirdId() {
        return pingAnThirdId;
    }

    public ReceiptsRechargeRecord setPingAnThirdId(String pingAnThirdId) {
        this.pingAnThirdId = pingAnThirdId;
        return this;
    }

    public ReceiptsRechargeRecord(Date chargeTime, String serialNumber, Double amount, String payType, Integer status, String pingAnThirdId) {
        this.chargeTime = chargeTime;
        this.serialNumber = serialNumber;
        this.amount = amount;
        this.payType = payType;
        this.status = status;
        this.pingAnThirdId = pingAnThirdId;
    }

    public ReceiptsRechargeRecord() {
    }

    /**
     * 支付的接口
     *
     * @param map
     */
    public ReceiptsRechargeRecord(HashMap<String, String> map, HashMap<String, String> userMap) {
        this.amount = Double.valueOf(map.get(KHField.AMOUNT));
        this.chargeTime = new Date();
        this.payType = map.get(KHField.PAYTYPE);
        this.pingAnThirdId = AssistantUtil.getThirdAssociatorID(userMap);
        this.serialNumber = map.get(KHField.ORDERID);
        this.status = RechargeEnum.TOBECOMFIRM.getCode();
    }


    @Override
    public String toString() {
        return "ReceiptsRechargeRecord{" +
                "id=" + id +
                ", chargeTime=" + chargeTime +
                ", serialNumber='" + serialNumber + '\'' +
                ", amount=" + amount +
                ", payType='" + payType + '\'' +
                ", status=" + status +
                ", pingAnThirdId='" + pingAnThirdId + '\'' +
                '}';
    }
}
