package com.uas.b2c.pay.repository;

import com.uas.b2c.pay.domain.AssociatorSubAccount;
import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.data.jpa.repository.JpaSpecificationExecutor;
import org.springframework.data.jpa.repository.Query;
import org.springframework.data.repository.query.Param;
import org.springframework.stereotype.Repository;

import java.util.List;

/**
 * 关联子账户的信息
 */
@Repository
public interface AssociatorSubAccountRepository extends JpaSpecificationExecutor<Long>, JpaRepository<AssociatorSubAccount, Long> {

    /**
     * 获取企业的子账户
     *
     * @param enuu 企业的enuu
     * @param isPesonal 一定是false
     * @return List<AssociatorSubAccount>
     */
    @Query(value = "select a from AssociatorSubAccount a where a.enuu = :enuu and a.isPersonal = :isPersonal order by a.id desc")
    List<AssociatorSubAccount> findByEnuuAndIsPersonal(@Param("enuu") Long enuu, @Param("isPersonal") Boolean isPesonal);


    /**
     * 获取不是游离的个人账户
     *
     * @param useruu 个人useruu
     * @param enuu 企业的enuu
     * @param isPersonal 必须是true
     * @param dissociative 必须是false
     * @return List<AssociatorSubAccount>
     */
    @Query(value = "select a from AssociatorSubAccount a where a.useruu = :useruu and a.enuu = :enuu "
            + "and a.isPersonal = :isPersonal and a.dissociative = :dissociative order by a.id")
    List<AssociatorSubAccount> findByUseruuAndEnuuAndIsPersonalAndDissociative(@Param("useruu") Long useruu,
                                                                               @Param("enuu") Long enuu,
                                                                               @Param("isPersonal") Boolean isPersonal,
                                                                               @Param("dissociative") Boolean dissociative);

    /**
     * 获取游离的个人账户
     *
     * @param useruu 个人uu
     * @param isPersonal 必须是true
     * @param dissociative 必须是true
     * @return
     */
    @Query(value = "select a from AssociatorSubAccount a where a.useruu = :useruu and a.isPersonal = :isPersonal "
            + "and a.dissociative = :dissociative order by a.id")
    List<AssociatorSubAccount> findByUseruuAndIsPersonalAndDissociative(@Param("useruu") Long useruu,
                                                                        @Param("isPersonal") Boolean isPersonal,
                                                                        @Param("dissociative") Boolean dissociative);


    /**
     * 根据会员编码查询 账户信息
     *
     * @param pingAnThirdId 第三方会员的代码
     * @return List<AssociatorSubAccount>
     */
    @Query(value = "select a from AssociatorSubAccount a where a.pingAnThirdId = :pingAnThirdId")
    List<AssociatorSubAccount> findAssociatorSubAccountByPingAnThirdId(@Param("pingAnThirdId") String pingAnThirdId);
}
