package com.uas.b2c.pay.service;

import com.uas.b2c.pay.assistant.ResultMap;
import com.uas.b2c.pay.domain.AssociatorSubAccount;

import java.util.HashMap;
import java.util.List;

/**
 * 资金汇总账户我们称为 BaseAccount
 * 子账户 我们称为 SubAccounnt
 * 会员子账户的服务类
 */
public interface AssociatorSubAccountService {

    /**
     * 开通子账户信息
     *
     * @param map 开户的信息
     * @return
     */
    ResultMap openSubAccount(HashMap<String, String> map);


//    /**
//     * 会员给账户充值
//     *
//     * @param map 充值账户信息
//     * @return
//     */
//    ResultMap rechargeAccount(HashMap map);

    /**
     * 单个保存信息
     *
     * @param associatorSubAccount
     * @return
     */
    AssociatorSubAccount save(AssociatorSubAccount associatorSubAccount);

    /**
     * 批量保存信息
     *
     * @param associatorSubAccounts
     * @return
     */
    List<AssociatorSubAccount> save(List<AssociatorSubAccount> associatorSubAccounts);

    /**
     * 获取资金汇总账户的信息
     *
     * @return
     */
    String getBaseAccountInfo();

    /**
     * 获取子账户的信息
     *
     * @param map 获取的子账户信息
     * @return
     */
    String getSubAccountInfo(HashMap map);

    /**
     * 获取 子账户的信息
     * @param enuu 企业uu 可以为空
     * @param useruu 个人uu 可以为空
     * @param isPersonal 个人/企业
     * @param dissociative 是否关联企业
     * @return AssociatorSubAccount
     */
    AssociatorSubAccount getAssociatorSubAccount(Long enuu, Long useruu, Boolean isPersonal, Boolean dissociative);


    /**
     * 查询银行在途清算结果【6108】
     *
     * @param map 传入的数据
     * @return
     */
    String querySettleAccounts(HashMap<String, String> map);


    /**
     * 查询子帐号历史余额及待转可提现状态信息【6114】
     *
     * @param map 传入的信息
     * @return String
     */
    String querySubAccountHistoryRemainderAndCanWithDrawInfo(HashMap<String, String> map);

    /**
     * 查询银行时间段内清分提现明细【6073】
     *
     * @param map 传入的数据
     * @return
     */
    String queryDistributionAndWithDrawDetail(HashMap<String, String> map);


    /**
     * 根据会员代码查询会员子账号【6092】
     *
     * @param map 传入的信息
     * @return String
     */
    String queryAccountInfo(HashMap<String, String> map);


    /**
     * 查询对账文件信息【6103】（余额，充值，体现，交易）
     *
     * @param map 传入的数据
     * @return String
     */
    String queryAccountStatement(HashMap<String, String> map);


    /**
     * 根据会员编码查询 账户信息
     *
     * @param pingAnThirdId 第三方会员的代码
     * @return List<AssociatorSubAccount>
     */
    AssociatorSubAccount findAssociatorSubAccountByPingAnThirdId(String pingAnThirdId);
}
