package com.uas.b2c.pay.service.impl;

import com.uas.b2c.pay.constant.PingAnField;
import com.uas.b2c.pay.service.AccountBindCardService;
import com.uas.b2c.pay.util.FastjsonUtils;
import com.uas.b2c.pay.util.InitMap;
import com.uas.b2c.pay.util.PingAnSendMessageUtil;
import com.uas.b2c.pay.util.PingAnTransfer;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.HashMap;

/**
 * 账户绑定银行卡的接口
 *
 * @author yuj 2018-01-02 23:23
 */
@Service
public class AccountBindCardServiceImpl implements AccountBindCardService {

    private final InitMap initMap;

    private final PingAnSendMessageUtil pingAnSendMessageUtil;

    private final PingAnTransfer pingAnTransfer;

    @Autowired
    public AccountBindCardServiceImpl(InitMap initMap, PingAnSendMessageUtil pingAnSendMessageUtil, PingAnTransfer pingAnTransfer) {
        this.initMap = initMap;
        this.pingAnSendMessageUtil = pingAnSendMessageUtil;
        this.pingAnTransfer = pingAnTransfer;
    }

    /**
     * 绑定提现账户 6066 银联鉴权
     *
     * @param map
     * @return
     */
    @Override
    public String unionPaybindBankCard(HashMap map) {
        HashMap parmaKeyDict = initMap.initUnionPaybindBankCard(map);
        //用于存放银行发送报文的参数
        HashMap retKeyDict = pingAnSendMessageUtil.sendMessage(parmaKeyDict);
        String str = (String) retKeyDict.get(PingAnField.RECEVEMESSAGE);
        HashMap hashMap = pingAnTransfer.parsingTranMessageString(str);
        String code = (String) hashMap.get(PingAnField.RSPCODE);
        String message = (String) hashMap.get(PingAnField.RESPONSEMESSAGE);
        return FastjsonUtils.toJson(hashMap);
    }

    /**
     * 绑定提现账户 - 用于会员填写动态验证码后，发往银行进行验证，验证成功则完成绑定。
     *
     * @param map
     * @return
     */
    @Override
    public String smsVerificationBindBankCard(HashMap<String, String> map) {
        HashMap<String, String> parmaKeyDict = initMap.initSmsVerificationBindBankCardMap(map);
        HashMap retKeyDict = pingAnSendMessageUtil.sendMessage(parmaKeyDict);
        String str = (String) retKeyDict.get(PingAnField.RECEVEMESSAGE);
        HashMap hashMap = pingAnTransfer.parsingTranMessageString(str);
        String code = (String) hashMap.get(PingAnField.RSPCODE);
        String message = (String) hashMap.get(PingAnField.RESPONSEMESSAGE);
        return FastjsonUtils.toJson(hashMap);
    }

    /**
     * 绑定提现账户 - 小额鉴权
     *
     * @param map 传入的数据
     * @return
     */
    @Override
    public String moneyBindBankCard(HashMap<String, String> map) {
        HashMap<String, String> parmaKeyDict = initMap.initMoneyBindBankCardMap(map);
        HashMap retKeyDict = pingAnSendMessageUtil.sendMessage(parmaKeyDict);
        String str = (String) retKeyDict.get(PingAnField.RECEVEMESSAGE);
        HashMap hashMap = pingAnTransfer.parsingTranMessageString(str);
        String code = (String) hashMap.get(PingAnField.RSPCODE);
        String message = (String) hashMap.get(PingAnField.RESPONSEMESSAGE);
        return FastjsonUtils.toJson(hashMap);
    }

    /**
     * 绑定提现账户 - 小额鉴权验证过程
     *
     * @param map
     * @return
     */
    @Override
    public String moneyVerificationBindBankCard(HashMap<String, String> map) {
        HashMap<String, String> parmaKeyDict = initMap.initMoneyVerificationBindBankCardMap(map);
        HashMap retKeyDict = pingAnSendMessageUtil.sendMessage(parmaKeyDict);
        String str = (String) retKeyDict.get(PingAnField.RECEVEMESSAGE);
        HashMap hashMap = pingAnTransfer.parsingTranMessageString(str);
        String code = (String) hashMap.get(PingAnField.RSPCODE);
        String message = (String) hashMap.get(PingAnField.RESPONSEMESSAGE);
        return FastjsonUtils.toJson(hashMap);
    }


    /**
     * 查询会员绑定的信息
     *
     * @param map 传入的参数
     * @return
     */
    @Override
    public String queryBindInfo(HashMap<String, String> map) {
        HashMap<String, String> parmaKeyDict = initMap.initqueryBindInfoMap(map);
        HashMap retKeyDict = pingAnSendMessageUtil.sendMessage(parmaKeyDict);
        String str = (String) retKeyDict.get(PingAnField.RECEVEMESSAGE);
        HashMap hashMap = pingAnTransfer.parsingTranMessageString(str);
        String code = (String) hashMap.get(PingAnField.RSPCODE);
        String message = (String) hashMap.get(PingAnField.RESPONSEMESSAGE);
        return FastjsonUtils.toJson(hashMap)+parmaKeyDict.get(PingAnField.THIRDLOGNO);
    }

    /**8888888888888888888888888888888888888888888
     * 会员解绑提现账户【6065】
     *
     * @param map
     * @return
     */
    @Override
    public String unbundlingCard(HashMap<String, String> map) {
        HashMap<String, String> parmaKeyDict = initMap.initUnbundlingCardMap(map);
        HashMap retKeyDict = pingAnSendMessageUtil.sendMessage(parmaKeyDict);
        String str = (String) retKeyDict.get(PingAnField.RECEVEMESSAGE);
        HashMap hashMap = pingAnTransfer.parsingTranMessageString(str);
        String code = (String) hashMap.get(PingAnField.RSPCODE);
        String message = (String) hashMap.get(PingAnField.RESPONSEMESSAGE);
        return FastjsonUtils.toJson(hashMap);
    }

    /**
     * 修改会员绑定的信息
     *
     * @param map 传入的信息
     * @return String
     */
    @Override
    public String modifyBindCardInfo(HashMap<String, String> map) {
        HashMap<String, String> parmaKeyDict = initMap.initModifyBindCardInfoMap(map);
        HashMap retKeyDict = pingAnSendMessageUtil.sendMessage(parmaKeyDict);
        String str = (String) retKeyDict.get(PingAnField.RECEVEMESSAGE);
        HashMap hashMap = pingAnTransfer.parsingTranMessageString(str);
        String code = (String) hashMap.get(PingAnField.RSPCODE);
        String message = (String) hashMap.get(PingAnField.RESPONSEMESSAGE);
        return FastjsonUtils.toJson(hashMap);
    }

    /**
     * 申请修改手机号码【6083】
     *
     * @param map 传入的数据
     * @return String
     */
    @Override
    public String modifyBindCardTelephone(HashMap<String, String> map) {
        HashMap<String, String> parmaKeyDict = initMap.initmodifyBindCardTelephoneMap(map);
        HashMap retKeyDict = pingAnSendMessageUtil.sendMessage(parmaKeyDict);
        String str = (String) retKeyDict.get(PingAnField.RECEVEMESSAGE);
        HashMap hashMap = pingAnTransfer.parsingTranMessageString(str);
        String code = (String) hashMap.get(PingAnField.RSPCODE);
        String message = (String) hashMap.get(PingAnField.RESPONSEMESSAGE);
        return FastjsonUtils.toJson(hashMap);
    }

    /**
     * 修改绑定的手机号 验证动态密码
     *
     * @param map
     * @return
     */
    @Override
    public String modifyBindCardTelephoneVerification(HashMap<String, String> map) {
        HashMap<String, String> parmaKeyDict = initMap.initModifyBindCardTelephoneVerificationMap(map);
        HashMap retKeyDict = pingAnSendMessageUtil.sendMessage(parmaKeyDict);
        String str = (String) retKeyDict.get(PingAnField.RECEVEMESSAGE);
        HashMap hashMap = pingAnTransfer.parsingTranMessageString(str);
        String code = (String) hashMap.get(PingAnField.RSPCODE);
        String message = (String) hashMap.get(PingAnField.RESPONSEMESSAGE);
        return FastjsonUtils.toJson(hashMap);
    }

    /**
     * 查询小额鉴权转账的结果
     *
     * @param map 查询的信息
     * @return
     */
    @Override
    public String queryMoneyBindCardResult(HashMap<String, String> map) {
        HashMap<String, String> parmaKeyDict = initMap.initQueryMoneyBindCardResultMap(map);
        HashMap retKeyDict = pingAnSendMessageUtil.sendMessage(parmaKeyDict);
        String str = (String) retKeyDict.get(PingAnField.RECEVEMESSAGE);
        HashMap hashMap = pingAnTransfer.parsingTranMessageString(str);
        String code = (String) hashMap.get(PingAnField.RSPCODE);
        String message = (String) hashMap.get(PingAnField.RESPONSEMESSAGE);
        return FastjsonUtils.toJson(hashMap);
    }
}
