package com.uas.b2c.pay.service.impl;

import com.uas.b2c.pay.assistant.CodeType;
import com.uas.b2c.pay.assistant.ResultMap;
import com.uas.b2c.pay.constant.PingAnField;
import com.uas.b2c.pay.constant.PingAnProperties;
import com.uas.b2c.pay.domain.AssociatorSubAccount;
import com.uas.b2c.pay.properties.SysConf;
import com.uas.b2c.pay.repository.AssociatorSubAccountRepository;
import com.uas.b2c.pay.service.AssociatorSubAccountService;
import com.uas.b2c.pay.util.FastjsonUtils;
import com.uas.b2c.pay.util.InitMap;
import com.uas.b2c.pay.util.PingAnSendMessageUtil;
import com.uas.b2c.pay.util.PingAnTransfer;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.collections.MapUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.util.StringUtils;

import java.util.HashMap;
import java.util.List;

/**
 * 开通子账户实现方法
 * @author yuj 2017-11-09 17:24
 *
 */
@Service
public class AssociatorSubAccountServiceImpl implements AssociatorSubAccountService {

    private final SysConf sysConf;

    private final AssociatorSubAccountRepository associatorSubAccountRepository;

    private final InitMap initMap;

    private final PingAnSendMessageUtil pingAnSendMessageUtil;

    private final PingAnTransfer pingAnTransfer;

    @Autowired
    public AssociatorSubAccountServiceImpl(SysConf sysConf,
                                           AssociatorSubAccountRepository associatorSubAccountRepository,
                                           PingAnTransfer pingAnTransfer,
                                           InitMap initMap, PingAnSendMessageUtil pingAnSendMessageUtil,
                                           PingAnTransfer pingAnTransfer1) {
        this.sysConf = sysConf;
        this.associatorSubAccountRepository = associatorSubAccountRepository;
        this.initMap = initMap;
        this.pingAnSendMessageUtil = pingAnSendMessageUtil;
        this.pingAnTransfer = pingAnTransfer1;
    }

    /**
     * 开通子账户信息
     *  map中包含 useruu enuu isPersonal(是个人账户，企业账户)， dissociative（是否是游离账户-个人账户）
     *
     * @param map
     * @return
     */
    @Override
    public ResultMap openSubAccount(HashMap<String, String> map) {
        //用于存放生成向银行请求报文的参数
        HashMap<String, String> parmaKeyDict = null;
        ResultMap resultMap = initMap.initOpenSubAccountMap(map);
        if (resultMap.getCode() == CodeType.success) {
            parmaKeyDict = (HashMap<String, String>) resultMap.getData();
        } else {
            return resultMap;
        }

        //用于存放银行发送报文的参数
        HashMap retKeyDict = pingAnSendMessageUtil.sendMessage(parmaKeyDict);
        //判断是否为空
        if (MapUtils.isEmpty(retKeyDict)) {
            return new ResultMap(CodeType.failure, "平安返回的信息为空", null);
        }
        //银行返回的报文
        String recvMessage = (String) retKeyDict.get(PingAnField.RECEVEMESSAGE);

        ResultMap result = null;
        HashMap returnMap = new HashMap();
        retKeyDict = pingAnTransfer.parsingTranMessageString(recvMessage);
        String rspCode = (String) retKeyDict.get(PingAnField.RSPCODE);

        if (PingAnProperties.RETURN_SUCCESS_CODE.equals(rspCode)) {
            AssociatorSubAccount sub = AssociatorSubAccount.createAssociatorSubAccount(map, retKeyDict, parmaKeyDict);
            AssociatorSubAccount persistAss = save(sub);
            returnMap.put(PingAnField.CUSTACCTID, retKeyDict.get(PingAnField.CUSTACCTID));
            returnMap.put("assid", persistAss.getId());
            result = new ResultMap(CodeType.success, "成功", returnMap);
        } else {
            result = new ResultMap(CodeType.failure, (String) retKeyDict.get(PingAnField.RESPONSEMESSAGE), null);
        }
        return result;
    }

//    /**
//     * 会员给账户充值
//     *
//     * @param map
//     * @return
//     */
//    @Override
//    public ResultMap rechargeAccount(HashMap map) {
//        HashMap paraMap = initMap.initRechargeAccount(map);
//
//        // 向银行发送信息
//        HashMap returnMap = pingAnSendMessageUtil.sendMessage(paraMap);
//
//        // 解析返回过来的信息
//        HashMap parsingMap = pingAnSendMessageUtil.parsingReturnMessage(returnMap);
//
//        String code = (String) parsingMap.get(PingAnField.RSPCODE);
//        String message = (String) parsingMap.get(PingAnField.RESPONSEMESSAGE);
//        return null;
//    }

    /**
     * 单个保存信息
     *
     * @param associatorSubAccount
     * @return
     */
    @Override
    public AssociatorSubAccount save(AssociatorSubAccount associatorSubAccount) {
        return associatorSubAccountRepository.save(associatorSubAccount);
    }

    /**
     * 批量保存信息
     *
     * @param associatorSubAccounts
     * @return
     */
    @Override
    public List<AssociatorSubAccount> save(List<AssociatorSubAccount> associatorSubAccounts) {
        return associatorSubAccountRepository.save(associatorSubAccounts);
    }

    /**
     * 获取资金汇总账户的信息
     *
     * @return
     */
    @Override
    public String getBaseAccountInfo() {
        HashMap hashMap1 = initMap.initGetBaseAccount();
        //向银行发送信息
        HashMap pingAnReturnMap = pingAnSendMessageUtil.sendMessage(hashMap1);
        if (MapUtils.isEmpty(pingAnReturnMap)) {
            throw new IllegalArgumentException("平安返回的信息为空");
        }

        // 解析银行的数据
        HashMap parsingMap = pingAnSendMessageUtil.parsingReturnMessage(pingAnReturnMap);
        String code = (String) parsingMap.get(PingAnField.RSPCODE);
        if (PingAnProperties.RETURN_SUCCESS_CODE.equals(code)) {
            String lastBalance = (String) parsingMap.get(PingAnField.LAST_BALANCE);
            String curBalance = (String) parsingMap.get(PingAnField.CUR_BALANCE);
            HashMap<String, String> resultMap = new HashMap<>();
            resultMap.put(PingAnField.LAST_BALANCE, lastBalance);
            resultMap.put(PingAnField.CUR_BALANCE, curBalance);
            return FastjsonUtils.toJson(resultMap);
        } else {
            String response = (String) parsingMap.get(PingAnField.RESPONSEMESSAGE);
            return response;
        }
    }

    /**
     * 获取子账户交易信息
     *
     * @return
     */
    @Override
    public String getSubAccountInfo(HashMap map) {
        if (MapUtils.isEmpty(map)) {
            throw new IllegalArgumentException("传入的账户信息为空");
        }
        HashMap hashMap = initMap.initGetSubAccountInfo(map);
        // 向银行发送信息
        HashMap pingAnReturnMap = pingAnSendMessageUtil.sendMessage(hashMap);
        // 解析银行的数据
        HashMap parsingMap = pingAnSendMessageUtil.parsingReturnMessage(pingAnReturnMap);
        String code = (String) parsingMap.get(PingAnField.RSPCODE);
        if (PingAnProperties.RETURN_SUCCESS_CODE.equals(code)) {
            return FastjsonUtils.toJson(parsingMap);
        } else {
            String response = String.valueOf(parsingMap.get(PingAnField.RESPONSEMESSAGE));
            return response;
        }
    }

    /**
     * 获取 子账户的信息
     *
     * @param enuu         企业uu 可以为空
     * @param useruu       个人uu 可以为空
     * @param isPersonal   个人/企业
     * @param dissociative 是否关联企业
     * @return AssociatorSubAccount
     */
    @Override
    public AssociatorSubAccount getAssociatorSubAccount(Long enuu, Long useruu, Boolean isPersonal, Boolean dissociative) {
        AssociatorSubAccount sub = null;
        List<AssociatorSubAccount> subAccounts = null;
        if (isPersonal) {
            if (useruu != null) {
                if (dissociative) {
                    subAccounts = associatorSubAccountRepository.findByUseruuAndIsPersonalAndDissociative(useruu, Boolean.TRUE, Boolean.TRUE);
                } else {
                    if (enuu != null) {
                        subAccounts = associatorSubAccountRepository.findByUseruuAndEnuuAndIsPersonalAndDissociative(useruu, enuu, isPersonal, dissociative);
                    } else {
                        throw new IllegalArgumentException("个人关联的企业的信息为空");
                    }
                }
            } else {
                throw new IllegalArgumentException("个人的信息为空");
            }

        } else {
            // 企业账户
            if (enuu != null) {
                subAccounts = associatorSubAccountRepository.findByEnuuAndIsPersonal(enuu, Boolean.FALSE);
            } else {
                throw new IllegalArgumentException("企业的信息为空");
            }
        }

        if (CollectionUtils.isNotEmpty(subAccounts)) {
            sub = subAccounts.get(0);
        }
        return sub;
    }

    /**
     * 查询银行在途清算结果【6108】
     *
     * @param map 传入的数据
     * @return
     */
    @Override
    public String querySettleAccounts(HashMap<String, String> map) {
        HashMap<String, String> parmaKeyDict = initMap.initQuerySettleAccountsMap(map);
        HashMap retKeyDict = pingAnSendMessageUtil.sendMessage(parmaKeyDict);
        String str = (String) retKeyDict.get(PingAnField.RECEVEMESSAGE);
        HashMap hashMap = pingAnTransfer.parsingTranMessageString(str);
        String code = (String) hashMap.get(PingAnField.RSPCODE);
        String message = (String) hashMap.get(PingAnField.RESPONSEMESSAGE);
        return null;
    }

    /**
     * 查询子帐号历史余额及待转可提现状态信息【6114】
     *
     * @param map 传入的信息
     * @return String
     */
    @Override
    public String querySubAccountHistoryRemainderAndCanWithDrawInfo(HashMap<String, String> map) {
        HashMap<String, String> parmaKeyDict = initMap.initQuerySubAccountHistoryRemainderAndCanWithDrawInfoMap(map);
        HashMap retKeyDict = pingAnSendMessageUtil.sendMessage(parmaKeyDict);
        String str = (String) retKeyDict.get(PingAnField.RECEVEMESSAGE);
        HashMap hashMap = pingAnTransfer.parsingTranMessageString(str);
        String code = (String) hashMap.get(PingAnField.RSPCODE);
        String message = (String) hashMap.get(PingAnField.RESPONSEMESSAGE);
        return null;
    }

    /**
     * 查询银行时间段内清分提现明细【6073】
     *
     * @param map 传入的数据
     * @return
     */
    @Override
    public String queryDistributionAndWithDrawDetail(HashMap<String, String> map) {
        HashMap<String, String> parmaKeyDict = initMap.initQueryDistributionAndWithDrawDetailMap(map);
        HashMap retKeyDict = pingAnSendMessageUtil.sendMessage(parmaKeyDict);
        String str = (String) retKeyDict.get(PingAnField.RECEVEMESSAGE);
        HashMap hashMap = pingAnTransfer.parsingTranMessageString(str);
        String code = (String) hashMap.get(PingAnField.RSPCODE);
        String message = (String) hashMap.get(PingAnField.RESPONSEMESSAGE);
        return null;
    }

    /**
     * 根据会员代码查询会员子账号【6092】
     *
     * @param map 传入的信息
     * @return String
     */
    @Override
    public String queryAccountInfo(HashMap<String, String> map) {
        HashMap<String, String> parmaKeyDict = initMap.initQueryAccountInfoMap(map);
        HashMap retKeyDict = pingAnSendMessageUtil.sendMessage(parmaKeyDict);
        String str = (String) retKeyDict.get(PingAnField.RECEVEMESSAGE);
        HashMap hashMap = pingAnTransfer.parsingTranMessageString(str);
        String code = (String) hashMap.get(PingAnField.RSPCODE);
        String message = (String) hashMap.get(PingAnField.RESPONSEMESSAGE);
        return null;
    }

    /**
     * 查询对账文件信息【6103】（余额，充值，体现，交易）
     *
     * @param map 传入的数据
     * @return String
     */
    @Override
    public String queryAccountStatement(HashMap<String, String> map) {
        HashMap<String, String> parmaKeyDict = initMap.initQueryAccountStatementMap(map);
        HashMap retKeyDict = pingAnSendMessageUtil.sendMessage(parmaKeyDict);
        String str = (String) retKeyDict.get(PingAnField.RECEVEMESSAGE);
        HashMap hashMap = pingAnTransfer.parsingTranMessageString(str);
        String code = (String) hashMap.get(PingAnField.RSPCODE);
        String message = (String) hashMap.get(PingAnField.RESPONSEMESSAGE);
        return null;
    }

    /**
     * 根据会员编码查询 账户信息
     *
     * @param pingAnThirdId 第三方会员的代码
     * @return List<AssociatorSubAccount>
     */
    @Override
    public AssociatorSubAccount findAssociatorSubAccountByPingAnThirdId(String pingAnThirdId) {
        if (StringUtils.isEmpty(pingAnThirdId)) {
            return null;
        } else {
            List<AssociatorSubAccount> subAccounts = associatorSubAccountRepository.findAssociatorSubAccountByPingAnThirdId(pingAnThirdId);
            if (CollectionUtils.isEmpty(subAccounts)) {
                return null;
            } else {
                return subAccounts.get(0);
            }
        }
    }
}
