package com.uas.b2c.pay.service.impl;

import com.uas.b2c.pay.assistant.CodeType;
import com.uas.b2c.pay.assistant.ResultMap;
import com.uas.b2c.pay.constant.PingAnField;
import com.uas.b2c.pay.constant.PingAnProperties;
import com.uas.b2c.pay.domain.PinganPayLog;
import com.uas.b2c.pay.properties.SysConf;
import com.uas.b2c.pay.repository.AssociatorSubAccountRepository;
import com.uas.b2c.pay.repository.PinganPayLogRepository;
import com.uas.b2c.pay.service.AssociatorTradeService;
import com.uas.b2c.pay.util.FastjsonUtils;
import com.uas.b2c.pay.util.InitMap;
import com.uas.b2c.pay.util.PingAnSendMessageUtil;
import com.uas.b2c.pay.util.PingAnTransfer;
import net.sf.json.JSONObject;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.scheduling.annotation.Async;
import org.springframework.stereotype.Service;

import java.util.Date;
import java.util.HashMap;

/**
 * 会员间交易的方法
 * @author yuj 2017-11-16 21:25
 */
@Service
public class AssociatorTradeServiceImpl implements AssociatorTradeService {

    private final SysConf sysConf;

    private final AssociatorSubAccountRepository associatorSubAccountRepository;

    private final PingAnTransfer pingAnTransfer;

    private final InitMap initMap;

    private final PingAnSendMessageUtil pingAnSendMessageUtil;

    @Autowired
    private PinganPayLogRepository pinganPayLogRepository;

    @Autowired
    public AssociatorTradeServiceImpl(SysConf sysConf, AssociatorSubAccountRepository associatorSubAccountRepository, PingAnTransfer pingAnTransfer, InitMap initMap, PingAnSendMessageUtil pingAnSendMessageUtil) {
        this.sysConf = sysConf;
        this.associatorSubAccountRepository = associatorSubAccountRepository;
        this.pingAnTransfer = pingAnTransfer;
        this.initMap = initMap;
        this.pingAnSendMessageUtil = pingAnSendMessageUtil;
    }

    /**
     * 买卖家支付方法
     *
     * @param map
     * @return
     */
    @Override
    public ResultMap payOrRefund(HashMap map) {
        HashMap parmaKeyDict = initMap.initPayOrRefundMap(map);
        HashMap retKeyDict = pingAnSendMessageUtil.sendMessage(parmaKeyDict);
        String str = (String) retKeyDict.get(PingAnField.RECEVEMESSAGE);
        HashMap hashMap = pingAnTransfer.parsingTranMessageString(str);
        String code = (String) hashMap.get(PingAnField.RSPCODE);
        String message = (String) hashMap.get(PingAnField.RESPONSEMESSAGE);
        return new ResultMap().setMessage(FastjsonUtils.toJson(hashMap));
    }


    /**
     * 会员充值
     *
     * @param map 传入的数据
     * @return String
     */
    @Override
    public String rechargeMember(HashMap<String, String> map) {
        HashMap<String, String> parmaKeyDict = initMap.initRechargeMemberMap(map);
        HashMap retKeyDict = pingAnSendMessageUtil.sendMessage(parmaKeyDict);
        String str = (String) retKeyDict.get(PingAnField.RECEVEMESSAGE);
        HashMap hashMap = pingAnTransfer.parsingTranMessageString(str);
        String code = (String) hashMap.get(PingAnField.RSPCODE);
        String message = (String) hashMap.get(PingAnField.RESPONSEMESSAGE);
        return FastjsonUtils.toJson(hashMap);
    }

    /**
     *
     * @param map
     * @return
     */
    @Override
    public ResultMap getSMSVerification(HashMap map) {
        HashMap hashMap = initMap.initSMSVerificationMap(map);
        HashMap returnMap = new HashMap();
        String message = pingAnTransfer.getTranMessage(hashMap);
        pingAnTransfer.SendTranMessage(message, sysConf.getB2biUrl(), sysConf.getServerPort(), returnMap);
        String recvMessage=(String)returnMap.get(PingAnField.RECEVEMESSAGE);//银行返回的报文
        HashMap hashMap1 = pingAnTransfer.parsingTranMessageString(recvMessage);
        pinganLogSave(hashMap,returnMap,message);
        String returnCode = (String)hashMap1.get(PingAnField.RSPCODE);
        System.out.println(JSONObject.fromObject(hashMap1));
        if(PingAnProperties.RETURN_SUCCESS_CODE.equals(returnCode)) {
            System.out.println(hashMap1.get("SerialNo"));
            System.out.println(hashMap1.get("RevMobilePhone"));
            return new ResultMap(CodeType.success, "获取成功", hashMap1.get("SerialNo"));
        }else {
            return new ResultMap(CodeType.failure, (String)hashMap1.get(PingAnField.RESPONSEMESSAGE), null);
        }
    }

    /**
     * 保存请求参数和应答参数;
     * @param parmaKeyDict
     * @param retKeyDict
     * @param tranMessage
     */
    @Async
    public void pinganLogSave(HashMap parmaKeyDict, HashMap retKeyDict, String tranMessage) {
        //请求日志存储到数据库中;
        PinganPayLog pinganPayLog = new PinganPayLog();
        pinganPayLog.setServType(1);
        pinganPayLog.setTranFunc((String) parmaKeyDict.get(PingAnField.TRANFUNC));
        pinganPayLog.setRequestNo((String)parmaKeyDict.get(PingAnField.THIRDLOGNO));
        pinganPayLog.setMemberId((String)parmaKeyDict.get(PingAnField.THIRDCUSTID));
        pinganPayLog.setUserRequestData(JSONObject.fromObject(parmaKeyDict).toString());
        pinganPayLog.setPinganRequestData(tranMessage);
        pinganPayLog.setRepdata((String)retKeyDict.get(PingAnField.RECEVEMESSAGE));
        pinganPayLog.setCreateDate(new Date());
        pinganPayLogRepository.save(pinganPayLog);
    }



    /**
     * 会员提现（验证短信验证码）【6085】
     *
     * @param map 传入的数据
     * @return String
     */
    @Override
    public String withdrawCashVerification(HashMap<String, String> map) {
        HashMap<String, String> parmaKeyDict = initMap.initWithdrawCashVerificationMap(map);
        HashMap retKeyDict = pingAnSendMessageUtil.sendMessage(parmaKeyDict);
        String str = (String) retKeyDict.get(PingAnField.RECEVEMESSAGE);
        HashMap hashMap = pingAnTransfer.parsingTranMessageString(str);
        String code = (String) hashMap.get(PingAnField.RSPCODE);
        String message = (String) hashMap.get(PingAnField.RESPONSEMESSAGE);
        return FastjsonUtils.toJson(hashMap)+parmaKeyDict.get(PingAnField.THIRDLOGNO);
    }

    /**
     * 申请提现
     *
     * @param map 申请提现的接口
     * @return
     */
    @Override
    public String expenditureApply(HashMap<String, String> map) {
        HashMap<String, String> parmaKeyDict = initMap.initExpenditureApplyMap(map);
        HashMap retKeyDict = pingAnSendMessageUtil.sendMessage(parmaKeyDict);
        String str = (String) retKeyDict.get(PingAnField.RECEVEMESSAGE);
        HashMap hashMap = pingAnTransfer.parsingTranMessageString(str);
        String code = (String) hashMap.get(PingAnField.RSPCODE);
        String message = (String) hashMap.get(PingAnField.RESPONSEMESSAGE);
        return null;
    }

    /**
     * 交易取消
     *
     * @param map 传入的数据
     * @return String
     */
    @Override
    public String tradeCallOff(HashMap<String, String> map) {
        HashMap<String, String> parmaKeyDict = initMap.initTradeCallOffMap(map);
        HashMap retKeyDict = pingAnSendMessageUtil.sendMessage(parmaKeyDict);
        String str = (String) retKeyDict.get(PingAnField.RECEVEMESSAGE);
        HashMap hashMap = pingAnTransfer.parsingTranMessageString(str);
        String code = (String) hashMap.get(PingAnField.RSPCODE);
        String message = (String) hashMap.get(PingAnField.RESPONSEMESSAGE);
        return null;
    }

    /**
     * 查询银行子账户余额 【6010】
     *
     * @param map 传入的数据
     * @return
     */
    @Override
    public String querySettleAccounts(HashMap<String, String> map) {
        HashMap<String, String> parmaKeyDict = initMap.initQuerySubAccountRemainderMap(map);
        HashMap retKeyDict = pingAnSendMessageUtil.sendMessage(parmaKeyDict);
        String str = (String) retKeyDict.get(PingAnField.RECEVEMESSAGE);
        HashMap hashMap = pingAnTransfer.parsingTranMessageString(str);
        String code = (String) hashMap.get(PingAnField.RSPCODE);
        String message = (String) hashMap.get(PingAnField.RESPONSEMESSAGE);
        return FastjsonUtils.toJson(hashMap);
    }

    /**
     * 查询单笔订单交易的状态
     *
     * @param map 传入的时间
     * @return String
     */
    @Override
    public String orderTradeStatus(HashMap<String, String> map) {
        HashMap<String, String> parmaKeyDict = initMap.initOrderTradeStatusMap(map);
        HashMap retKeyDict = pingAnSendMessageUtil.sendMessage(parmaKeyDict);
        String str = (String) retKeyDict.get(PingAnField.RECEVEMESSAGE);
        HashMap hashMap = pingAnTransfer.parsingTranMessageString(str);
        String code = (String) hashMap.get(PingAnField.RSPCODE);
        String message = (String) hashMap.get(PingAnField.RESPONSEMESSAGE);
        return FastjsonUtils.toJson(hashMap);
    }

    /**
     * 查询提现退单
     *
     * @param map 传入的数据
     * @return
     */
    @Override
    public String queryWithdrawChargeBack(HashMap<String, String> map) {
        HashMap<String, String> parmaKeyDict = initMap.initQueryWithdrawChargeBackMap(map);
        HashMap retKeyDict = pingAnSendMessageUtil.sendMessage(parmaKeyDict);
        String str = (String) retKeyDict.get(PingAnField.RECEVEMESSAGE);
        HashMap hashMap = pingAnTransfer.parsingTranMessageString(str);
        String code = (String) hashMap.get(PingAnField.RSPCODE);
        String message = (String) hashMap.get(PingAnField.RESPONSEMESSAGE);
        return FastjsonUtils.toJson(hashMap);
    }

    /**
     * 查询普通转账充值的明细
     *
     * @param map 传入的数据
     * @return String
     */
    @Override
    public String queryTransferAccountsDetail(HashMap<String, String> map) {
        HashMap<String, String> parmaKeyDict = initMap.initQueryTransferAccountsDetailMap(map);
        HashMap retKeyDict = pingAnSendMessageUtil.sendMessage(parmaKeyDict);
        String str = (String) retKeyDict.get(PingAnField.RECEVEMESSAGE);
        HashMap hashMap = pingAnTransfer.parsingTranMessageString(str);
        String code = (String) hashMap.get(PingAnField.RSPCODE);
        String message = (String) hashMap.get(PingAnField.RESPONSEMESSAGE);
        return FastjsonUtils.toJson(hashMap);
    }

    /**
     * 查询子账户交易的记录
     *
     * @param map 输入的信息
     * @return String
     */
    @Override
    public String queryAccountTradeInfo(HashMap<String, String> map) {
        HashMap<String, String> parmaKeyDict = initMap.initQueryAccountTradeInfoMap(map);
        HashMap retKeyDict = pingAnSendMessageUtil.sendMessage(parmaKeyDict);
        String str = (String) retKeyDict.get(PingAnField.RECEVEMESSAGE);
        HashMap hashMap = pingAnTransfer.parsingTranMessageString(str);
        String code = (String) hashMap.get(PingAnField.RSPCODE);
        String message = (String) hashMap.get(PingAnField.RESPONSEMESSAGE);
        return FastjsonUtils.toJson(hashMap);
    }

    /**
     * （挂账子账户中余额转到对应的子账户）
     *
     * @param map
     * @return
     */
    @Override
    public String distributionSpecialAccount(HashMap<String, String> map) {
        HashMap<String, String> parmaKeyDict = initMap.initDistributionSpecialAccountMap(map);
        HashMap retKeyDict = pingAnSendMessageUtil.sendMessage(parmaKeyDict);
        String str = (String) retKeyDict.get(PingAnField.RECEVEMESSAGE);
        HashMap hashMap = pingAnTransfer.parsingTranMessageString(str);
        String code = (String) hashMap.get(PingAnField.RSPCODE);
        String message = (String) hashMap.get(PingAnField.RESPONSEMESSAGE);
        return FastjsonUtils.toJson(hashMap);
    }

    /**
     * 查询充值明细（见证+收单）【6146】
     *
     * @param map 传入的订单号
     * @return String
     */
    @Override
    public String queryRechargeDetail(HashMap<String, String> map) {
        HashMap<String, String> parmaKeyDict = initMap.initQueryRechargeDetailMap(map);
        HashMap retKeyDict = pingAnSendMessageUtil.sendMessage(parmaKeyDict);
        String str = (String) retKeyDict.get(PingAnField.RECEVEMESSAGE);
        HashMap hashMap = pingAnTransfer.parsingTranMessageString(str);
        String code = (String) hashMap.get(PingAnField.RSPCODE);
        String message = (String) hashMap.get(PingAnField.RESPONSEMESSAGE);
        return FastjsonUtils.toJson(hashMap);
    }

    /**
     * 调账(见证+收单)【6145】
     *
     * @param map
     * @return
     */
    @Override
    public String adjustAccount(HashMap<String, String> map) {
        HashMap<String, String> parmaKeyDict = initMap.initAdjustAccountMap(map);
        HashMap retKeyDict = pingAnSendMessageUtil.sendMessage(parmaKeyDict);
        String str = (String) retKeyDict.get(PingAnField.RECEVEMESSAGE);
        HashMap hashMap = pingAnTransfer.parsingTranMessageString(str);
        String code = (String) hashMap.get(PingAnField.RSPCODE);
        String message = (String) hashMap.get(PingAnField.RESPONSEMESSAGE);
        return FastjsonUtils.toJson(hashMap);
    }

    /**
     * 平台补账
     *
     * @param map
     * @return
     */
    @Override
    public String makeUpAccount(HashMap<String, String> map) {
        HashMap<String, String> parmaKeyDict = initMap.initMakeUpAccountMap(map);
        HashMap retKeyDict = pingAnSendMessageUtil.sendMessage(parmaKeyDict);
        String str = (String) retKeyDict.get(PingAnField.RECEVEMESSAGE);
        HashMap hashMap = pingAnTransfer.parsingTranMessageString(str);
        String code = (String) hashMap.get(PingAnField.RSPCODE);
        String message = (String) hashMap.get(PingAnField.RESPONSEMESSAGE);
        return FastjsonUtils.toJson(hashMap);
    }
}
