package com.uas.b2c.pay.service.impl;

import com.uas.b2c.pay.assistant.CodeType;
import com.uas.b2c.pay.assistant.ResultMap;
import com.uas.b2c.pay.constant.IntegerConstant;
import com.uas.b2c.pay.constant.KHField;
import com.uas.b2c.pay.constant.PayCardTypeEnum;
import com.uas.b2c.pay.constant.PayTypeEnum;
import com.uas.b2c.pay.constant.StringConstant;
import com.uas.b2c.pay.domain.AssociatorSubAccount;
import com.uas.b2c.pay.domain.ReceiptsRechargeRecord;
import com.uas.b2c.pay.properties.SysConf;
import com.uas.b2c.pay.repository.PinganPayLogRepository;
import com.uas.b2c.pay.service.EBankService;
import com.uas.b2c.pay.service.ReceiptsRechargeRecordService;
import com.uas.b2c.pay.util.AssistantUtil;
import com.uas.b2c.pay.util.KHUtil;
import com.uas.b2c.pay.util.NumberUtil;
import com.uas.b2c.pay.util.StringUtil;
import com.uas.b2c.pay.util.TimeToString;
import com.uas.b2c.pay.util.UserInfoUtil;
import org.apache.commons.collections.MapUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.util.StringUtils;

import java.util.Date;
import java.util.HashMap;

/**
 * 网关支付的实现类
 *
 * @author yuj 2017-12-29 0:35
 */
@Service
public class EBankServiceImpl implements EBankService {

    private final UserInfoUtil userInfoUtil;

    private final SysConf sysConf;

    private final PinganPayLogRepository pinganPayLogRepository;

    private final ReceiptsRechargeRecordService receiptsRechargeRecordService;

    @Autowired
    public EBankServiceImpl(UserInfoUtil userInfoUtil, SysConf sysConf, PinganPayLogRepository pinganPayLogRepository, ReceiptsRechargeRecordService receiptsRechargeRecordService) {
        this.userInfoUtil = userInfoUtil;
        this.sysConf = sysConf;
        this.pinganPayLogRepository = pinganPayLogRepository;
        this.receiptsRechargeRecordService = receiptsRechargeRecordService;
    }

    /**
     * 网关支付的解耦
     *
     * @param map 传入的支付接口数据
     * @return String
     */
    @Override
    public ResultMap eBankPay(HashMap<String, String> map) {
        HashMap<String, String> initEBankMap = null;
        ResultMap resultMap = initEBank(map);
        if (resultMap.getCode() == CodeType.success) {
            initEBankMap = (HashMap<String, String>) resultMap.getData();
        } else {
            return resultMap;
        }
//        KeyedCollection keyedCollection = BankCardAcceptanceUtil.mapConvertToKeyedCollectionAfterSignature(initEBankMap, KHField.INPUT);
//        if (keyedCollection == null) {
//            return new ResultMap(CodeType.failure, "组装的信息为空", null);
//        }
//        Map<String, String> postMap = new HashedMap();
//        String orig = (String) keyedCollection.get(KHField.ORIG);
//        String sign = (String) keyedCollection.get(KHField.SIGN);
//        postMap.put(KHField.ORIG, orig);
//        postMap.put(KHField.SIGN, sign);
//        postMap.put(KHField.PAGE_FLAG, StringConstant.DEFAULT_PAGE_FLAG);
//        postMap.put(KHField.RETURNURL, sysConf.geteBankReturnUrl());
//        postMap.put(KHField.NOTIFYURL, sysConf.geteBankNotifyUrl());
//       // pinganLogSave(initEBankMap, postMap);
//        String httpClientPost = BankCardAcceptanceUtil.httpClientPost(postMap, sysConf.getPayUrl());
//        return new ResultMap(CodeType.success, "成功", httpClientPost);
        ReceiptsRechargeRecord rechargeRecord = new ReceiptsRechargeRecord(initEBankMap, map);
        receiptsRechargeRecordService.save(rechargeRecord);
        return new ResultMap(CodeType.success, "成功", initEBankMap.get(KHField.ORDERID));
    }



    /**
     * 初始化数据
     *
     * @param map 数据map
     * @return map
     */
    public ResultMap initEBank(HashMap<String, String> map) {
        HashMap<String, String> hashMap = new HashMap<>();
        if (MapUtils.isEmpty(map)) {
            return new ResultMap(CodeType.failure, "传入的数据为空", null);
        }
        AssociatorSubAccount associatorSubAccountByUserInfo = userInfoUtil.getAssociatorSubAccountByUserInfo(map);
        if (associatorSubAccountByUserInfo == null) {
            return new ResultMap(CodeType.failure, "找不到对应的会员信息", null);
        }
        String subAccountid = associatorSubAccountByUserInfo.getSubAccountid();
        if (StringUtils.isEmpty(subAccountid)) {
            return new ResultMap(CodeType.failure, "找不到对应的会员信息", null);
        } else {
            hashMap.put(KHField.CUSTOMERID, subAccountid);
        }
        hashMap.put(KHField.MASTERID, sysConf.getMasterId());
        String orderId = KHUtil.getOrderId(sysConf.getMasterId());
        hashMap.put(KHField.ORDERID, orderId);
        hashMap.put(KHField.CURRENCY, StringConstant.RMB_CURRENCY);
        hashMap.put(KHField.PAYDATE, TimeToString.timeToString(new Date(), StringConstant.YMDHMS));
        String amout = map.get(KHField.AMOUNT);
        if (StringUtils.isEmpty(amout)) {
            return new ResultMap(CodeType.failure, "传入的总金额的信息为空", null);
        }
        hashMap.put(KHField.AMOUNT, String.valueOf(NumberUtil.fractionNumHalfUp(amout, IntegerConstant.FRACTION)));
        hashMap.put(KHField.OBJECTNAME, StringUtil.getString(map.get(KHField.OBJECTNAME)));
        hashMap.put(KHField.VALIDTIME, StringConstant.ZERO_STRING);
        String payType = map.get(KHField.PAYTYPE);
        if (StringUtils.isEmpty(payType)) {
            return new ResultMap(CodeType.failure, "传入的支付方式为空", null);
        } else {
            if (PayTypeEnum.B2B_EBANK.getValue().equals(payType)) {
                hashMap.put(KHField.PAYTYPE, PayTypeEnum.B2B_EBANK.getValue());
                hashMap.put(KHField.PAYCARDTYPE, PayCardTypeEnum.MIX_CARD.getValue());
            } else if (PayTypeEnum.B2C_EBANK.getValue().equals(payType)) {
                hashMap.put(KHField.PAYTYPE, PayTypeEnum.B2C_EBANK.getValue());
            } else {
                return new ResultMap(CodeType.failure, "传入的支付方式有误", null);
            }
        }

        String issInsCode = map.get(KHField.ISSINSCODE);
        if (StringUtils.isEmpty(issInsCode)) {
            return new ResultMap(CodeType.failure, "传入的发卡机构代码信息为空", null);
        } else {
            hashMap.put(KHField.ISSINSCODE, issInsCode);
        }
        hashMap.put(KHField.ISSINSCODE, issInsCode);

        String payCardType = map.get(KHField.PAYCARDTYPE);
        if (PayTypeEnum.B2C_EBANK.getValue().equals(payType)) {
            if (PayCardTypeEnum.DEBIT_CARD.getValue().equals(payCardType) ||
                    PayCardTypeEnum.SAVINGS_CARD.getValue().equals(payCardType)) {
                hashMap.put(KHField.PAYCARDTYPE, payCardType);
            } else {
                return new ResultMap(CodeType.failure, "银行卡类型（贷记卡/借记卡）", null);
            }
        }
        String remark = AssistantUtil.produceRemark(sysConf.getBusinessCode(), StringConstant.ZERO_STRING, StringConstant.MIN_POSITIVE_INTEGER, subAccountid);
        hashMap.put(KHField.REMARK, remark);
        return new ResultMap(CodeType.success, "成功", hashMap);
    }
}
