package com.uas.b2c.pay.service.impl;

import com.ecc.emp.data.KeyedCollection;
import com.uas.b2c.pay.assistant.CodeType;
import com.uas.b2c.pay.assistant.ResultMap;
import com.uas.b2c.pay.constant.KHField;
import com.uas.b2c.pay.constant.PayTypeEnum;
import com.uas.b2c.pay.constant.StringConstant;
import com.uas.b2c.pay.constant.UnionPayBusinessCodeConstant;
import com.uas.b2c.pay.domain.AssociatorSubAccount;
import com.uas.b2c.pay.domain.ReceiptsRechargeRecord;
import com.uas.b2c.pay.properties.SysConf;
import com.uas.b2c.pay.service.AssociatorSubAccountService;
import com.uas.b2c.pay.service.KHUnionPayQuikService;
import com.uas.b2c.pay.service.ReceiptsRechargeRecordService;
import com.uas.b2c.pay.util.BankCardAcceptanceUtil;
import com.uas.b2c.pay.util.FastjsonUtils;
import com.uas.b2c.pay.util.InitMap;
import com.uas.b2c.pay.util.KHUtil;
import com.uas.b2c.pay.util.PingAnParseResult;
import com.uas.b2c.pay.util.StringUtil;
import com.uas.b2c.pay.util.TimeToString;
import com.uas.b2c.pay.util.UserInfoUtil;
import org.apache.commons.collections.MapUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.util.StringUtils;

import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 银联支付的实现层
 *
 * @author yuj 2017-12-21 15:16
 */
@Service
public class KHUnionPayQuikServiceImpl implements KHUnionPayQuikService {

    private final UserInfoUtil userInfoUtil;

    private final SysConf sysConf;

    private final InitMap initMap;

    private final ReceiptsRechargeRecordService receiptsRechargeRecordService;

    @Autowired
    public KHUnionPayQuikServiceImpl(AssociatorSubAccountService associatorSubAccountService, UserInfoUtil userInfoUtil, SysConf sysConf, InitMap initMap, ReceiptsRechargeRecordService receiptsRechargeRecordService) {
        this.userInfoUtil = userInfoUtil;
        this.sysConf = sysConf;
        this.initMap = initMap;
        this.receiptsRechargeRecordService = receiptsRechargeRecordService;
    }

    /**
     * 根据用户的信息，组装签名等信息
     *
     * @param map 用户的一些信息
     * @return 返回的绑卡的信息，让B2C执行
     */
    @Override
    public ResultMap kHBindCard(HashMap<String, String> map) {
        if (MapUtils.isEmpty(map)) {
            return new ResultMap(CodeType.failure, "传入的用户信息丢失", null);
        }
        AssociatorSubAccount associatorSubAccount = userInfoUtil.getAssociatorSubAccountByUserInfo(map);
        String subAccountid = null;
        if (associatorSubAccount == null) {
            return new ResultMap(CodeType.failure, "找不到对应的会员信息", null);
        } else {
            subAccountid = associatorSubAccount.getSubAccountid();
            if (StringUtils.isEmpty(subAccountid)) {
                return new ResultMap(CodeType.failure, "该会员没有对应的id信息", null);
            }
        }

        Map<String, String> khBindCardMap = initKHBindCardMap(subAccountid);
        KeyedCollection afterSignature = BankCardAcceptanceUtil.mapConvertToKeyedCollectionAfterSignature(khBindCardMap, KHField.INPUT);
        if (afterSignature == null) {
            return new ResultMap(CodeType.failure, "生成的请求体信息为空", null);
        }
        afterSignature.put(KHField.RETURNURL, sysConf.getBindCardReturnUrl());
        afterSignature.put(KHField.NOTIFYURL, sysConf.getBindCardNotifyUrl());
        //绑卡的接口必须要用form表单提交
        String clientPost = BankCardAcceptanceUtil.httpClientPost(BankCardAcceptanceUtil.keyedCollectionToMap(afterSignature), sysConf.getBindCardUrl());
        if (clientPost == null) {
            return new ResultMap(CodeType.failure, "请求返回的数据为空", null);
        } else {
            return new ResultMap(CodeType.success, "成功", clientPost.replaceAll("[\\n\\r]", ""));
        }
    }


    /**
     * 初始化跨行绑卡的map
     *
     * @param customerId 客户的id
     * @return Map<String, String>
     */
    @Override
    public Map<String, String> initKHBindCardMap(String customerId) {
        if (StringUtils.isEmpty(customerId)) {
            throw new IllegalArgumentException("传入的信息为空");
        }
        HashMap<String, String> map = new HashMap<>();
        String masterId = sysConf.getMasterId();
        String orderId = KHUtil.getOrderId(masterId);
        SimpleDateFormat simpleDateFormat = new SimpleDateFormat(StringConstant.YMDHMS);
        String format = simpleDateFormat.format(new Date());

        map.put(KHField.MASTERID, masterId);
        map.put(KHField.ORDERID, orderId);
        map.put(KHField.DATETIME, format);
        map.put(KHField.CUSTOMERID, customerId);
        return map;
    }

    /**
     * 根据用户信息查询绑卡信息
     *
     * @param map 用户的信息
     * @return 绑卡信息
     */
    @Override
    public ResultMap queryBindCards(HashMap<String, String> map) {
        if (MapUtils.isEmpty(map)) {
            return new ResultMap(CodeType.failure, "传入的用户信息丢失", null);
        }
        AssociatorSubAccount associatorSubAccount = userInfoUtil.getAssociatorSubAccountByUserInfo(map);
        if (associatorSubAccount == null) {
            return new ResultMap(CodeType.failure, "找不到对应的会员信息", null);
        }
        String subAccountid = associatorSubAccount.getSubAccountid();
        if (StringUtils.isEmpty(subAccountid)) {
            return new ResultMap(CodeType.failure, "该会员没有对应的id信息", null);
        }
        HashMap<String, String> upMap = new HashMap<>();
        upMap.put(KHField.MASTERID, sysConf.getMasterId());
        upMap.put(KHField.CUSTOMERID, subAccountid);

        KeyedCollection keyedCollection = BankCardAcceptanceUtil.getKeyedCollectionFromMap(upMap, KHField.INPUT);
        if (MapUtils.isEmpty(keyedCollection)) {
            return new ResultMap(CodeType.failure, "生成的请求体信息为空", null);
        }
        KeyedCollection message = BankCardAcceptanceUtil.postMessage(keyedCollection, UnionPayBusinessCodeConstant.UNIONPAY_QUERY_CARD);
        List<Map<String, String>> maps = PingAnParseResult.parseQueryBindCard(message);
        return new ResultMap(CodeType.success, "成功", FastjsonUtils.toJSON(maps));
    }

    /**
     * 快捷支付的短信接口
     *
     * @param map 包含的支付信息
     * @return String 返回的信息
     */
    @Override
    public String khPaySMS(HashMap<String, String> map) {
//        AssociatorSubAccount associatorSubAccount = userInfoUtil.getAssociatorSubAccountByUserInfo(map);
//        if (associatorSubAccount == null) {
//            throw new IllegalArgumentException("找不到对应的会员信息");
//        }
//        String subAccountid = associatorSubAccount.getSubAccountid();
//        if (StringUtils.isEmpty(subAccountid)) {
//            throw new IllegalArgumentException("该会员没有对应的id信息");
//        }
//        map.put(KHField.CUSTOMERID, subAccountid);
//        Map<String, String> paySMSMap = initkhPaySMSMap(map);
//        KeyedCollection keyedCollection = BankCardAcceptanceUtil.getKeyedCollectionFromMap(paySMSMap, KHField.INPUT);
//        if (keyedCollection == null) {
//            throw new IllegalArgumentException("返回的数据为空");
//        }
//        KeyedCollection message = BankCardAcceptanceUtil.postMessage(keyedCollection, UnionPayBusinessCodeConstant.UNIONPAY_SMS);
//        Map<String, String> stringMap = BankCardAcceptanceUtil.keyedCollectionToMap(message);
//        if (stringMap == null) {
//            return "";
//        } else {
//            //stringMap.get(PingAnField.)
//            return FastjsonUtils.toJson(stringMap);
//        }

        return "短信动态码111111";
    }

    /**
     * 初始化快捷支付发送短信的接口
     *
     * @param map 需要转的map
     * @return
     */
    private Map<String, String> initkhPaySMSMap(Map<String, String> map) {
        if (MapUtils.isEmpty(map)) {
            throw new IllegalStateException("传入的信息为空");
        }
        HashMap<String, String> resultMap = new HashMap<>();

        String currency = map.get(KHField.CURRENCY);
        if (StringUtils.isEmpty(currency)) {
            // 目前平安只支持人民币
            currency = StringConstant.RMB_CURRENCY;
        }
        resultMap.put(KHField.CURRENCY, currency);

        String orderId = KHUtil.getOrderId(sysConf.getMasterId());
        System.out.println(orderId);
        resultMap.put(KHField.ORDERID, orderId);

        String amount = map.get(KHField.AMOUNT);
        String money = KHUtil.formaterMoney(amount);
        resultMap.put(KHField.AMOUNT, money);

        resultMap.put(KHField.OBJECTNAME, StringUtil.getString(map.get(KHField.OBJECTNAME)));
        resultMap.put(KHField.MASTERID, sysConf.getMasterId());
        resultMap.put(KHField.CUSTOMERID, map.get(KHField.CUSTOMERID));
        resultMap.put(KHField.PAYTYPE, PayTypeEnum.UNION_PAY.getValue());
        resultMap.put(KHField.VALIDTIME, StringConstant.ZERO_STRING);
        //目前 openid 字段设置 为 客户的id信息
        resultMap.put(KHField.OPENID, map.get(KHField.OPENID));
        resultMap.put(KHField.PAYDATE, TimeToString.timeToString(new Date(), StringConstant.YMDHMS));
        resultMap.put(KHField.REMARK, StringUtil.getString(map.get(KHField.REMARK)));

        return resultMap;
    }


    /**
     * 银联的支付动作接口
     *
     * @param map 传入的数据
     * @return 结果json 字符串
     */
    @Override
    public ResultMap khPay(HashMap<String, String> map) {
        if (MapUtils.isEmpty(map)) {
            return new ResultMap(CodeType.failure, "传入的信息为空", null);
        }
        ResultMap resultMap = initMap.khPayMap(map);
        HashMap<String, String> hashMap = null;
        if (resultMap.getCode() == CodeType.success) {
            hashMap = (HashMap<String, String>) resultMap.getData();
        } else {
            return resultMap;
        }

//        KeyedCollection keyedCollection = BankCardAcceptanceUtil.getKeyedCollectionFromMap(hashMap, KHField.INPUT);
//        if (keyedCollection == null) {
//            return new ResultMap(CodeType.failure, "组装之后的数据为空", null);
//        }
//        KeyedCollection message = BankCardAcceptanceUtil.postMessage(keyedCollection, UnionPayBusinessCodeConstant.PAYMENT);
//
//        Map<String, String> stringMap = BankCardAcceptanceUtil.keyedCollectionToMap(message);
//        if (stringMap == null) {
//            return new ResultMap(CodeType.failure, "平安返回过来的数据为空", null);
//        } else {
//            return new ResultMap(CodeType.success, "成功", FastjsonUtils.toJson(stringMap));
//        }
        ReceiptsRechargeRecord rechargeRecord = new ReceiptsRechargeRecord(hashMap, map);
        receiptsRechargeRecordService.save(rechargeRecord);
        return new ResultMap(CodeType.success, "成功", hashMap.get(KHField.ORDERID));
    }
}
