package com.uas.b2c.pay.service.impl;

import com.ecc.emp.data.KeyedCollection;
import com.uas.b2c.pay.assistant.CodeType;
import com.uas.b2c.pay.assistant.ResultMap;
import com.uas.b2c.pay.constant.KHField;
import com.uas.b2c.pay.constant.PayTypeEnum;
import com.uas.b2c.pay.constant.StringConstant;
import com.uas.b2c.pay.constant.UnionPayBusinessCodeConstant;
import com.uas.b2c.pay.domain.AssociatorSubAccount;
import com.uas.b2c.pay.domain.ReceiptsRechargeRecord;
import com.uas.b2c.pay.properties.SysConf;
import com.uas.b2c.pay.service.KHUnionPayQuikService;
import com.uas.b2c.pay.service.ReceiptsRechargeRecordService;
import com.uas.b2c.pay.service.WeChatService;
import com.uas.b2c.pay.util.BankCardAcceptanceUtil;
import com.uas.b2c.pay.util.InitMap;
import com.uas.b2c.pay.util.KHUtil;
import com.uas.b2c.pay.util.StringUtil;
import com.uas.b2c.pay.util.TimeToString;
import com.uas.b2c.pay.util.UserInfoUtil;
import org.apache.commons.collections.MapUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.util.StringUtils;

import java.util.Date;
import java.util.HashMap;

/**
 * 微信支付的实现类
 *
 * @author yuj 2017-12-28 0:15
 */
@Service
public class WeChatServiceImpl implements WeChatService {

    private final SysConf sysConf;

    private final KHUnionPayQuikService kHUnionPayQuikService;

    private final UserInfoUtil userInfoUtil;

    private final InitMap initMap;

    private final ReceiptsRechargeRecordService receiptsRechargeRecordService;

    @Autowired
    public WeChatServiceImpl(SysConf sysConf, KHUnionPayQuikService kHUnionPayQuikService, UserInfoUtil userInfoUtil, InitMap initMap, ReceiptsRechargeRecordService receiptsRechargeRecordService) {
        this.sysConf = sysConf;
        this.kHUnionPayQuikService = kHUnionPayQuikService;
        this.userInfoUtil = userInfoUtil;
        this.initMap = initMap;
        this.receiptsRechargeRecordService = receiptsRechargeRecordService;
    }

    /**
     * 微信的预支付
     *
     * @param map 传入的数据
     * @return 返回结果集
     */
    @Override
    public String prePayment(HashMap<String, String> map) {
        initPreWeChatPay(map);
        KeyedCollection keyedCollectionFromMap = BankCardAcceptanceUtil.getKeyedCollectionFromMap(map, UnionPayBusinessCodeConstant.UNIONPAY_SMS);
        KeyedCollection keyedCollection = BankCardAcceptanceUtil.getKeyedCollectionFromMap(map, KHField.INPUT);
        if (MapUtils.isEmpty(keyedCollection)) {
            throw new IllegalArgumentException("生成的请求体信息为空");
        }
        KeyedCollection message = BankCardAcceptanceUtil.postMessage(keyedCollection, UnionPayBusinessCodeConstant.PAYMENT);
        if (keyedCollection == null) {
            throw new IllegalArgumentException("返回的数据为空");
        }
        return message == null ? "" : message.toString();
    }

    /**
     * 验证预支付传入的信息
     *
     * @param map 传入的数据
     * @return void
     */
    private void initPreWeChatPay(HashMap<String,String> map) {
        if (MapUtils.isEmpty(map)) {
            throw new IllegalArgumentException("传入的数据为空");
        }
        AssociatorSubAccount associatorSubAccountByUserInfo = userInfoUtil.getAssociatorSubAccountByUserInfo(map);
        //        if (associatorSubAccount == null) {
        //            throw new IllegalArgumentException("找不到对应的会员信息");
        //        }
        //        String subAccountid = associatorSubAccount.getSubAccountid();
        String subAccountid = "19901120";
        if (StringUtils.isEmpty(subAccountid)) {
            throw new IllegalArgumentException("该会员没有对应的id信息");
        } else {
            map.put(KHField.CUSTOMERID, subAccountid);
        }
        map.put(KHField.MASTERID, sysConf.getMasterId());
        map.put(KHField.CURRENCY, StringConstant.RMB_CURRENCY);

        String orderId = KHUtil.getOrderId(sysConf.getMasterId());
        map.put(KHField.ORDERID, orderId);

        String money = map.get(KHField.AMOUNT);
        String amout = KHUtil.formaterMoney(money);
        map.put(KHField.AMOUNT, amout);

        map.put(KHField.OBJECTNAME, StringUtil.getString(map.get(KHField.OBJECTNAME)));

        map.put(KHField.PAYDATE, TimeToString.timeToString(new Date(), StringConstant.YMDHMS));
        map.put(KHField.PAYTYPE, PayTypeEnum.WECHAT_PAY.getValue());
    }


    /**
     * 微信的支付接口
     *
     * @param map 传入的数据
     * @return String
     */
    @Override
    public ResultMap payment(HashMap<String, String> map) {
        ResultMap resultMap = initMap.initWeChatPaymentMap(map);
        HashMap<String, String> hashMap = null;
        if (resultMap.getCode() == CodeType.success) {
            hashMap = (HashMap<String, String>) resultMap.getData();
        } else {
            return resultMap;
        }
//        KeyedCollection keyedCollection = BankCardAcceptanceUtil.getKeyedCollectionFromMap(hashMap, KHField.INPUT);
//        if (MapUtils.isEmpty(keyedCollection)) {
//            throw new IllegalArgumentException("生成的请求体信息为空");
//        }
//        KeyedCollection message = BankCardAcceptanceUtil.postMessage(keyedCollection, UnionPayBusinessCodeConstant.PAYMENT);
//        return message == null ? "" : message.toString();

        ReceiptsRechargeRecord rechargeRecord = new ReceiptsRechargeRecord(hashMap, map);
        receiptsRechargeRecordService.save(rechargeRecord);
        return new ResultMap(CodeType.success, "成功", hashMap.get(KHField.ORDERID));
    }
}
