package com.uas.b2c.pay.util;

import com.uas.b2c.pay.constant.B2CField;
import com.uas.b2c.pay.constant.KHField;
import com.uas.b2c.pay.constant.PingAnProperties;
import com.uas.b2c.pay.constant.StringConstant;
import org.springframework.util.StringUtils;

import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.Map;
import java.util.Random;

/**
 * 辅助方法
 *
 * @author yuj 2017-11-09 20:25
 */
public class AssistantUtil {

    static final char[] DIGITS = {'0', '1', '2', '3', '4', '5', '6', '7',
            '8', '9', 'A', 'B', 'C', 'D', 'E', 'F',
            'G', 'H', 'J', 'K', 'L', 'M', 'N',  'P',
            'R', 'S', 'T', 'U', 'W', 'X', 'Y', 'Z'};

    /**
     * 传入个人的uu
     * @return 返回20位的数字
     */
    public static String getThirdLogNo() {
        // 生成随机数:当前精确到秒的时间再加8位的数字随机序列,用于生成请求流水号
        //设置日期格式
        SimpleDateFormat df = new SimpleDateFormat("yyyyMMddHHmmss");
        String rdNum = df.format(new Date());
        String part1 = numericToString(Long.valueOf(rdNum), PingAnProperties.DECIMAL);
        Random random = new Random();
        int ird = random.nextInt(999999);
        String part2 = numericToString(Long.valueOf(ird), PingAnProperties.DECIMAL);

        //赋值请求流水号
        String thirdLogNo = paddingStr(part1 + part2, PingAnProperties.LENGTH);
        return thirdLogNo;
    }

    /**
     * 生成唯一的平台会员
     * @param map 传入的用户信息
     * @return 返回
     */
    public static String getThirdAssociatorID(HashMap<String, String> map) {
        Long useruu = null;
        Long enuu = null;
        Boolean isPersonal = null;
        Boolean dissociative = null;
        try {
            isPersonal = Boolean.valueOf(map.get(B2CField.ISPERSONAL));
            dissociative = Boolean.valueOf(map.get(B2CField.DISSOCIATIVE));
            if (isPersonal) {
                useruu = Long.valueOf(map.get(B2CField.USERUU));
            }
            if (!dissociative) {
                enuu = Long.valueOf(map.get(B2CField.ENUU));
            }
        } catch (NumberFormatException e) {
            throw new IllegalArgumentException("传入的个人账户信息格式不正确");
        }
        String id = (useruu != null ? String.valueOf(useruu) : StringConstant.DEFAULTUSERUU) + (String.valueOf(enuu == null ? "" : enuu)) + String.valueOf(isPersonal ? 1 : 0) + String.valueOf(dissociative ? 1 : 0);
        return id;
    }

    /**
     * 将十进制的数字转换为指定进制的字符串。
     *
     * @param i
     *            十进制的数字。
     * @param system
     *            指定的进制，常见的2/8/16/32。
     * @return 转换后的字符串。
     */
    public static String numericToString(Long i, Integer system) {
        long num = 0;
        if (i < 0) {
            num = ((long) 2 * 0x7fffffff) + i + 2;
        } else {
            num = i;
        }
        char[] buf = new char[32];
        int charPos = 32;
        while ((num / system) > 0) {
            buf[--charPos] = DIGITS[(int) (num % system)];
            num /= system;
        }
        buf[--charPos] = DIGITS[(int) (num % system)];
        return new String(buf, charPos, (32 - charPos));
    }
    /**
     * 将其它进制的数字（字符串形式）转换为十进制的数字。
     *
     * @param s
     *            其它进制的数字（字符串形式）
     * @param system
     *            指定的进制，常见的2/8/16。
     * @return 转换后的数字。
     */
    public static int stringToNumeric(String s, int system) {
        char[] buf = new char[s.length()];
        s.getChars(0, s.length(), buf, 0);
        long num = 0;
        for (int i = 0; i < buf.length; i++) {
            for (int j = 0; j < DIGITS.length; j++) {
                if (DIGITS[j] == buf[i]) {
                    num += j * Math.pow(system, buf.length - i - 1);
                    break;
                }
            }
        }
        return (int) num;
    }

    /**
     * 填充字符传的到指定长度
     * @param str 需要填充的字符串
     * @param length 长度信息
     * @return
     */
    public static String paddingStr(String str, Integer length) {
        if (str == null || length == null) {
            return null;
        }
        if (str.length() >= length) {
            return str;
        } else {
            int i = length - str.length();
            for (int j = 0; j < i; j++) {
                str += "0";
            }
            return str;
        }
    }

    /**
     * 格式化 第几页
     *
     * @return String
     */
    public static String formatePageNum(String pageNum) {
        if (StringUtils.isEmpty(pageNum)) {
            pageNum = StringConstant.MIN_POSITIVE_INTEGER;
        } else {
            try {
                Integer page = Integer.valueOf(pageNum);
            } catch (NumberFormatException e) {
                pageNum = StringConstant.MIN_POSITIVE_INTEGER;
            }
        }
        return pageNum;
    }

    /**
     * 生成收单系统的remark 字段
     *
     * @param businesscode 企业代码
     * @param tranFee 手续费
     * @param payType 支付方式
     * @param custAcctId 会员号
     * @return
     */
    public static String produceRemark(String businesscode, String tranFee, String payType, String custAcctId) {
        ArrayList listsum =new ArrayList();
        Map<String, Object> dataMap0 = new HashMap<String, Object>();
        ArrayList list =new ArrayList();
        Map<String, String> dataMap = new HashMap<String, String>();
        dataMap.put(KHField.SUBACCNO, custAcctId);//入账会员子账户 子帐号
        dataMap.put(KHField.PAYMODEL, payType);//0-冻结支付 1-普通支付 支付模式，根据需要模式赋值0或者1
        dataMap.put(KHField.TRANFEE, tranFee);// 手续费
        list.add(dataMap);
        dataMap0.put(KHField.ODERLIST, list);
        dataMap0.put(KHField.REMARKTYPE, StringConstant.REMARKTYPE);//备注类型-SDS0100000 统一赋值为SDS0100000
        dataMap0.put(KHField.PLANTCODE, businesscode);//见证系统提供
        dataMap0.put(KHField.SFJORDERTYPE,  StringConstant.ZERO_STRING);//0-普通支付订单，1-子订单信息   目前统一赋值为0
        listsum.add(dataMap0);
        String json = FastjsonUtils.toJson(listsum);
        String resultStr = json.replaceAll("\"", "&quot;");
        return resultStr;
    }


}
