package com.uas.b2c.pay.util;

import com.ecc.emp.data.DataField;
import com.ecc.emp.data.IndexedCollection;
import com.ecc.emp.data.KeyedCollection;
import com.sdb.payclient.bean.exception.CsiiException;
import com.sdb.payclient.core.PayclientInterfaceUtil;
import com.uas.b2c.pay.constant.KHField;
import com.uas.b2c.pay.domain.PinganPayLog;
import com.uas.b2c.pay.repository.PinganPayLogRepository;
import net.sf.json.JSONObject;
import org.apache.commons.collections.MapUtils;
import org.apache.http.HttpEntity;
import org.apache.http.client.entity.UrlEncodedFormEntity;
import org.apache.http.client.methods.CloseableHttpResponse;
import org.apache.http.client.methods.HttpPost;
import org.apache.http.impl.client.CloseableHttpClient;
import org.apache.http.impl.client.HttpClientBuilder;
import org.apache.http.message.BasicNameValuePair;
import org.apache.http.util.EntityUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.util.StringUtils;

import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.Set;

/**
 * 银行收单辅助工具类（跨行快收的接口）
 *
 * @author yuj 2017-12-21 9:08
 */
public class BankCardAcceptanceUtil {


    @Autowired
    private static PinganPayLogRepository pinganPayLogRepository;

    /**
     * map 转 KeyedCollection
     *
     * @param map 需要转的map
     * @param name KeyedCollection 的名字
     * @return KeyedCollection
     */
    public static KeyedCollection mapToKeyedCollection(Map<String, String> map, String name) {
        if (MapUtils.isEmpty(map)) {
            return null;
        }
        KeyedCollection keyedCollection = null;
        if (StringUtils.isEmpty(name)) {
            keyedCollection = new KeyedCollection();
        } else {
            keyedCollection = new KeyedCollection(name);
        }
        Set<Map.Entry<String, String>> entrySet = map.entrySet();
        Iterator<Map.Entry<String, String>> iterator = entrySet.iterator();
        while (iterator.hasNext()) {
            Map.Entry<String, String> next = iterator.next();
            keyedCollection.put(next.getKey(), next.getValue());
        }
        return keyedCollection;
    }

    /**
     * keyedCollection对象转成map 对象
     *
     * @param keyedCollection 需要转的值
     * @return Map<String, String>
     */
    public static Map<String, String> keyedCollectionToMap(KeyedCollection keyedCollection) {
        HashMap<String, String> map = new HashMap<>();
        if (keyedCollection == null) {
            return null;
        }
        Set<Map.Entry<String, Object>> entrySet = keyedCollection.entrySet();
        for (Map.Entry<String, Object> entry : entrySet) {
            Object object = entry.getValue();
            if (object instanceof IndexedCollection) {
                Map<String, String> map1 = objectToMap(object);
                map.putAll(map1);
            } else if (object instanceof DataField) {
                DataField field = (DataField) object;
                map.put(entry.getKey(), StringUtil.getString(field.getValue()));
            } else if (object instanceof KeyedCollection) {
                Map<String, String> map1 = objectToMap(object);
                map.putAll(map1);
            } else {
                //TODO
                System.out.println("存在其他的情况");
            }
        }
        return map;
    }


    /**
     * map 转 KeyedCollection
     *
     * @param map 需要转的map
     * @param name KeyedCollection 的名字
     * @return KeyedCollection
     */
    public static KeyedCollection getKeyedCollectionFromMap(Map<String, String> map, String name) {
        if (MapUtils.isEmpty(map)) {
            return null;
        }
        KeyedCollection input = null;
        if (StringUtils.isEmpty(name)) {
            input = new KeyedCollection();
        } else {
            input = new KeyedCollection(name);
        }
        Set<Map.Entry<String, String>> entrySet = map.entrySet();
        for (Map.Entry<String, String> entry : entrySet) {
            input.put(entry.getKey(), entry.getValue());
        }
        return input;
    }

    /**
     * 向指定的地址发送地址
     *
     * @param map 请求体的参数
     * @param actionUrl 发送请求的地址
     * @return 返回请求的结果地址
     */
    public static String httpClientPost(Map<String, String> map, String actionUrl) {
        if (MapUtils.isEmpty(map) || StringUtils.isEmpty(actionUrl)) {
            return null;
        }

        HttpClientBuilder clientBuilder = HttpClientBuilder.create();
        CloseableHttpClient build = clientBuilder.build();
        HttpPost httpPost = new HttpPost(actionUrl);
        List<BasicNameValuePair> list = new ArrayList<>();
        Set<Map.Entry<String, String>> entrySet = map.entrySet();
        for (Map.Entry<String, String> entry : entrySet) {
            list.add(new BasicNameValuePair(entry.getKey(), entry.getValue()));
        }
        UrlEncodedFormEntity urlEncodedFormEntity = null;
        try {
            urlEncodedFormEntity = new UrlEncodedFormEntity(list);
        } catch (UnsupportedEncodingException e) {
            e.printStackTrace();
        }
        httpPost.setEntity(urlEncodedFormEntity);
        HttpEntity httpEntity = null;
        String entityStr = null;
        try {
            CloseableHttpResponse httpResponse = build.execute(httpPost);
            httpEntity = httpResponse.getEntity();
            if (httpEntity != null) {
                entityStr = EntityUtils.toString(httpEntity, "UTF-8");
            } else {
                throw new IllegalArgumentException("平安银行传过来的信息为空");
            }
        } catch (IOException e) {
            e.printStackTrace();
        }
        pinganLogSave(map, entityStr);
        return entityStr;
    }

    /**
     * 请求响应数据保存
     * @param map
     * @param entityStr
     */
    public static void pinganLogSave(Map<String, String> map, String entityStr) {
        PinganPayLog pinganPayLog = new PinganPayLog();
        pinganPayLog.setPinganRequestData(JSONObject.fromObject(map).toString());
        pinganPayLog.setRepdata(entityStr);
        pinganPayLog.setCreateDate(new Date());
       // pinganPayLogRepository.save(pinganPayLog);
    }

    /**
     * 向银行发送的外部接口
     *
     * @param input 需要传输的数据，
     * @param businessCode 业务的数据
     * @return 返回的KeyedCollection
     */
    public static KeyedCollection postMessage(KeyedCollection input, String businessCode) {
        PayclientInterfaceUtil util = null;
        KeyedCollection keyedCollection = null;
        try {
            util = new PayclientInterfaceUtil();
            keyedCollection = util.execute(input, businessCode);
            pinganLogSave(input,JSONObject.fromObject(keyedCollection).toString());
        } catch (CsiiException e) {
            e.printStackTrace();
        } catch (Exception e) {
            e.printStackTrace();
        }
        return keyedCollection;
    }


    /**
     * 传入map加入签名之后 转成KeyedCollection
     *
     * @param map 需要加入签名的数据
     * @return KeyedCollection
     */
    public static KeyedCollection mapConvertToKeyedCollectionAfterSignature(Map<String, String> map, String name) {
        KeyedCollection input = getKeyedCollectionFromMap(map, name);
        if (input == null) {
            throw new IllegalArgumentException("产品的信息为空，请重新操作");
        }
        KeyedCollection outPut = new KeyedCollection();
        PayclientInterfaceUtil util = null;
        String orig = null;
        String sign = null;
        String encoding = "GBK";
        try {
            util = new PayclientInterfaceUtil();
            KeyedCollection signData = util.getSignData(input);
            orig = (String)signData.getDataValue(KHField.ORIG);
            sign = (String)signData.getDataValue(KHField.SIGN);
            orig = util.Base64Encode(orig, encoding);
            sign = util.Base64Encode(sign, encoding);
            orig = java.net.URLEncoder.encode(orig, encoding);
            sign = java.net.URLEncoder.encode(sign, encoding);
        } catch (CsiiException e) {
            e.printStackTrace();
        } catch (Exception e) {
            e.printStackTrace();
        }
        outPut.put(KHField.ORIG, orig);
        outPut.put(KHField.SIGN, sign);
        return outPut;
    }


    public static Map<String, String> objectToMap(Object obj) {
        HashMap<String, String> map = new HashMap<>();
        if (obj instanceof IndexedCollection) {
            IndexedCollection  indexedCollection = (IndexedCollection) obj;
            Iterator iterator = indexedCollection.iterator();
            while (iterator.hasNext()) {
                Object next = iterator.next();
                Map<String, String> map1 = objectToMap(next);
                map.putAll(map1);
            }
        } else if (obj instanceof KeyedCollection) {
            KeyedCollection keyedCollection = (KeyedCollection) obj;
            Set<Map.Entry<String, Object>> entrySet = keyedCollection.entrySet();
            for (Map.Entry<String, Object> entry : entrySet) {
                String key = entry.getKey();
                Object value = entry.getValue();
                if (value instanceof DataField) {
                    DataField field = (DataField) value;
                    map.put(key, String.valueOf(field.getValue()));
                } else {
                    Map<String, String> map1 = objectToMap(value);
                    map.putAll(map1);
                }
            }
        }

        return map;
    }
}
