package com.uas.b2c.pay.util;

import com.uas.b2c.pay.assistant.CodeType;
import com.uas.b2c.pay.assistant.ResultMap;
import com.uas.b2c.pay.constant.B2CField;
import com.uas.b2c.pay.constant.IntegerConstant;
import com.uas.b2c.pay.constant.KHField;
import com.uas.b2c.pay.constant.PayTypeEnum;
import com.uas.b2c.pay.constant.PingAnEnum;
import com.uas.b2c.pay.constant.PingAnField;
import com.uas.b2c.pay.constant.PingAnProperties;
import com.uas.b2c.pay.constant.StringConstant;
import com.uas.b2c.pay.constant.TranFunc;
import com.uas.b2c.pay.domain.AssociatorSubAccount;
import com.uas.b2c.pay.properties.SysConf;
import org.apache.commons.collections.MapUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.util.StringUtils;

import java.util.HashMap;

/**
 * 初始化传送的map
 * @author yuj 2017-11-22 18:12
 */
@Service
public class InitMap {

    private final SysConf sysconf;

    private final UserInfoUtil userInfoUtil;

    @Autowired
    public InitMap(SysConf sysconf, UserInfoUtil userInfoUtil) {
        this.sysconf = sysconf;
        this.userInfoUtil = userInfoUtil;
    }

    public HashMap<String, String> initSendMap(String tranFunc) {
        HashMap<String, String> map = new HashMap();
        map.put(PingAnField.QYDM, sysconf.getBusinessCode());       //
        map.put(PingAnField.SUPACCTID, sysconf.getFundSummaryAccount()); //资金汇总账号
        // 报文头参数赋值
        String thirdLogNo = AssistantUtil.getThirdLogNo();
        map.put(PingAnField.THIRDLOGNO, thirdLogNo);
        //交易码，此处以【6000】接口为例子
        map.put(PingAnField.TRANFUNC, tranFunc);
        return map;
    }

    /**
     * 初始化需要传的map
     * @param map
     * @return
     */
    public HashMap<String, String> initPayOrRefundMap(HashMap<String, String> map) {
        HashMap parmaKeyDict = initSendMap(TranFunc.MEMBER_TRADE);
        if (map.get(B2CField.USERUU) == null) {
            throw new IllegalArgumentException("参数丢失");
        }
        String funcFlag = map.get(PingAnField.FUNCFLAG);
        if (StringConstant.PRE_PAYMENT.equals(funcFlag) || StringConstant.CONFIRM_PAY.equals(funcFlag) || StringConstant.DIRECT_PAY.equals(funcFlag) || StringConstant.REFUND_PAY.equals(funcFlag)) {
            parmaKeyDict.put(PingAnField.FUNCFLAG, funcFlag);
        } else {
            throw new IllegalArgumentException("传入的支付类型为空");
        }

        String outCustAccid = String.valueOf(map.get(PingAnField.OUTCUSTACCTID));
        if (StringUtils.isEmpty(outCustAccid)) {
            throw new IllegalArgumentException("转出子账户为空");
        }
        parmaKeyDict.put(PingAnField.OUTCUSTACCTID, outCustAccid);

        String OutThirdCustId = String.valueOf(map.get(PingAnField.OUTTHIRDCUSTID));
        if (StringUtils.isEmpty(OutThirdCustId)) {
            throw new IllegalArgumentException("转出会员代码");
        }
        parmaKeyDict.put(PingAnField.OUTTHIRDCUSTID, OutThirdCustId);

        // 转出的资金需要从user信息中获取
        String outThirdCustId = map.get(PingAnField.OUTCUSTACCTID);
        String outCustName = map.get(PingAnField.OUTCUSTNAME);
        parmaKeyDict.put(PingAnField.OUTCUSTACCTID, outThirdCustId);
        parmaKeyDict.put("OutCustName", outCustName);
        parmaKeyDict.put("InCustAcctId", map.get("InCustAcctId"));
        parmaKeyDict.put("InThirdCustId", map.get("InThirdCustId"));
        parmaKeyDict.put("InCustName", map.get("InCustName"));
        String tranAmount = map.get(PingAnField.TRANAMOUNT);
        if (StringUtils.isEmpty(tranAmount)) {
            throw new IllegalArgumentException("传入的总金额为空");
        } else {
            try {
                Double aDouble = Double.valueOf(tranAmount);
            } catch (NumberFormatException e) {
                throw new IllegalArgumentException("传入的不全是数字");
            }
        }
        parmaKeyDict.put(PingAnField.TRANAMOUNT, NumberUtil.fractionNumHalfUp(tranAmount, IntegerConstant.FRACTION)+"");

        String tranFee = map.get(PingAnField.TRANFEE);
        if (StringUtils.isEmpty(tranFee)) {
            tranFee = StringConstant.ZERO_STRING;
        }
        parmaKeyDict.put(PingAnField.TRANFEE, tranFee);

        parmaKeyDict.put(PingAnField.TRANTYPE, StringConstant.NORMAL_TRANSITION);
        parmaKeyDict.put(PingAnField.CCYCODE, StringConstant.RMB_CURRENCY);
        parmaKeyDict.put("ThirdHtId", map.get("ThirdHtId"));
        parmaKeyDict.put("ThirdHtMsg", map.get("ThirdHtMsg"));
        parmaKeyDict.put("Note", map.get("Note"));
        String messageCode = map.get(PingAnField.MESSAGE_CODE);
        if (StringUtils.isEmpty(messageCode)) {
            throw new IllegalArgumentException("传入的短信验证码为空");
        }
        parmaKeyDict.put(PingAnField.MESSAGE_CODE, messageCode);
        parmaKeyDict.put("Reserve", map.get("Reserve"));
        parmaKeyDict.put("SerialNo", map.get("SerialNo"));
        return parmaKeyDict;
    }

    /**
     * 获取短信验证码
     * @return
     */
    public HashMap initSMSVerificationMap(HashMap map) {
        HashMap parmaKeyDict = initSendMap(TranFunc.MESSAGE_VERIFICATION);
        parmaKeyDict.put("ThirdCustId", map.get("ThirdCustId"));
        parmaKeyDict.put("CustAcctId", map.get("CustAcctId"));
        parmaKeyDict.put("TranType", map.get("TranType"));
        parmaKeyDict.put("TranAmount", map.get("TranAmount"));
        return parmaKeyDict;
    }


    /**
     * 获取短信验证码
     * @return
     */
    public HashMap initWithdrawCashVerificationMap(HashMap<String, String> map) {
        HashMap parmaKeyDict = initSendMap(TranFunc.WITHDRAWCASH);
       /* AssociatorSubAccount userInfo = userInfoUtil.getAssociatorSubAccountByUserInfo(map);
        if (userInfo == null) {
            throw new IllegalArgumentException("请先开通账号");
        }*/
        /*parmaKeyDict.put(PingAnField.CUSTACCTID, userInfo.getSubAccountid());
        parmaKeyDict.put(PingAnField.THIRDCUSTID, userInfo.getPingAnThirdId());*/

        parmaKeyDict.put(PingAnField.CUSTACCTID, map.get(PingAnField.CUSTACCTID));
        parmaKeyDict.put(PingAnField.THIRDCUSTID, map.get(PingAnField.THIRDCUSTID));
        String custName = map.get(PingAnField.CUSTNAME);
        if (StringUtils.isEmpty(custName)) {
            throw new IllegalArgumentException("传入的子账户名称为空");
        }
        parmaKeyDict.put(PingAnField.CUSTNAME, custName);

        String outAcctId = map.get(PingAnField.OUTACCTID);
        if (StringUtils.isEmpty(outAcctId)) {
            throw new IllegalArgumentException("传入的提现账号为空");
        }
        parmaKeyDict.put(PingAnField.OUTACCTID, outAcctId);

        String outAcctIdName = map.get(PingAnField.OUTACCTIDNAME);
        if (StringUtils.isEmpty(outAcctIdName)) {
            throw new IllegalArgumentException("传入的提现账户名称为空");
        }
        parmaKeyDict.put(PingAnField.OUTACCTIDNAME, outAcctIdName);
        parmaKeyDict.put(PingAnField.CCYCODE, StringConstant.RMB_CURRENCY);
        String tranAmout = map.get(PingAnField.TRANAMOUNT);
        if (StringUtils.isEmpty(tranAmout)) {
            throw new IllegalArgumentException("提现金额为空");
        }
        parmaKeyDict.put(PingAnField.TRANAMOUNT, tranAmout);

        String handFee = map.get(PingAnField.HANDFEE);
        if (StringUtils.isEmpty(handFee)) {
            handFee = StringConstant.ZERO_STRING;
        } else {
            try {
                Double aDouble = Double.valueOf(handFee);
            } catch (NumberFormatException e) {
                handFee = StringConstant.ZERO_STRING;
            }
        }
        parmaKeyDict.put(PingAnField.HANDFEE, handFee);

        String serialNo = map.get(PingAnField.SERIALNO);
        if (StringUtils.isEmpty(serialNo)) {
            throw new IllegalArgumentException("传入的短信指令号为空");
        }
        parmaKeyDict.put(PingAnField.SERIALNO, serialNo);

        String messageCode = map.get(PingAnField.MESSAGE_CODE);
        if (StringUtils.isEmpty(messageCode)) {
            throw new IllegalArgumentException("传入的短信验证码为空");
        }
        parmaKeyDict.put(PingAnField.MESSAGE_CODE, messageCode);

        //TODO 网银签名 当使用支付密码验证时，必输

        return parmaKeyDict;
    }

    /**
     * 会员提现或支付申请
     *
     * @param map 传入的数据
     * @return
     */
    public HashMap initExpenditureApplyMap(HashMap<String, String> map) {
        HashMap parmaKeyDict = initSendMap(TranFunc.TRADE_CALL_OFF);
        AssociatorSubAccount userInfo = userInfoUtil.getAssociatorSubAccountByUserInfo(map);
        if (userInfo == null) {
            throw new IllegalArgumentException("请先开通账号");
        }
        parmaKeyDict.put(PingAnField.CUSTACCTID, userInfo.getSubAccountid());
        parmaKeyDict.put(PingAnField.THIRDCUSTID, userInfo.getPingAnThirdId());

        String tranType = map.get(PingAnField.TRANTYPE);
        if (StringConstant.TRANSACTION_WITHDRAW.equals(tranType) || StringConstant.TRANSACTION_PAY.equals(tranType)) {
            parmaKeyDict.put(PingAnField.TRANTYPE, tranType);
        }
        String tranAmout = map.get(PingAnField.TRANAMOUNT);
        if (StringUtils.isEmpty(tranAmout)) {
            throw new IllegalArgumentException("交易金额为空");
        }
        parmaKeyDict.put(PingAnField.TRANAMOUNT, tranAmout);
        return parmaKeyDict;
    }

    /**
     * 会员提现或支付申请
     *
     * @param map 传入的数据
     * @return
     */
    public HashMap initTradeCallOffMap(HashMap<String, String> map) {
        HashMap parmaKeyDict = initSendMap(TranFunc.EXPENDITURE_APPLY);

        String funcFlag = map.get(PingAnField.FUNCFLAG);
        if (StringConstant.CALLOFF_BOTH.equals(funcFlag) ||
                StringConstant.CALLOFF_CLEARING.equals(funcFlag) || StringConstant.CALLOFF_FROZEN.equals(funcFlag)) {
            parmaKeyDict.put(PingAnField.FUNCFLAG, funcFlag);
        } else {
            throw new IllegalArgumentException("传入撤销类型为空");
        }

        String origThirdLogNo = map.get(PingAnField.ORIGTHIRDLOGNO);
        if (StringUtils.isEmpty(origThirdLogNo)) {
            throw new IllegalArgumentException("需要撤销的流水号为空");
        }
        return parmaKeyDict;
    }

    /**
     * 查询银行在途清算结果【6108】
     *
     * @param map 传入的数据
     * @return
     */
    public HashMap initQuerySettleAccountsMap(HashMap<String, String> map) {
        HashMap parmaKeyDict = initSendMap(TranFunc.QUERY_SETTLEACCOUNTS);

        String funcFlag = map.get(PingAnField.FUNCFLAG);
        if (StringConstant.QUERY_SETTLEACCOUNT_RESULT_ALL.equals(funcFlag) || StringConstant.QUERY_SETTLEACCOUNT_RESULT_SPECIFIED_TIME.equals(funcFlag)) {
            parmaKeyDict.put(PingAnField.FUNCFLAG, funcFlag);
        } else {
            throw new IllegalArgumentException("传入的查询类型为空，所有或指定时间段");
        }

        String pageNum = map.get(PingAnField.PAGENUM);
        String page = AssistantUtil.formatePageNum(pageNum);
        parmaKeyDict.put(PingAnField.PAGENUM, page);


        if (StringConstant.QUERY_SETTLEACCOUNT_RESULT_SPECIFIED_TIME.equals(funcFlag)) {
            String beginDate = map.get(PingAnField.BEGINDATE);
            if (StringUtils.isEmpty(beginDate)) {
                throw new IllegalArgumentException("传入的开始时间为空");
            }
            parmaKeyDict.put(PingAnField.BEGINDATE, beginDate);

            String endDate = map.get(PingAnField.ENDDATE);
            if (StringUtils.isEmpty(endDate)) {
                throw new IllegalArgumentException("传入的结束时间为空");
            }
            parmaKeyDict.put(PingAnField.ENDDATE, endDate);
        }
        return parmaKeyDict;
    }

    /**
     * 查询子帐号历史余额及待转可提现状态信息【6114】
     *
     * @param map 传入的数据
     * @return
     */
    public HashMap initQuerySubAccountHistoryRemainderAndCanWithDrawInfoMap(HashMap<String, String> map) {
        HashMap parmaKeyDict = initSendMap(TranFunc.QUERY_SUBACCOUNTHISTORY_REMAINDERAND_CANWITHDRAWINFO);
        AssociatorSubAccount accountByUserInfo = userInfoUtil.getAssociatorSubAccountByUserInfo(map);
//        if (accountByUserInfo == null) {
//            throw new IllegalArgumentException("您还未开户，请先开户");
//        }
        parmaKeyDict.put(PingAnField.CUSTACCTID, "3239000000006067");

        String beginDate = map.get(PingAnField.BEGINDATE);
        String endDate = map.get(PingAnField.ENDDATE);
        if (!StringUtils.isEmpty(beginDate)&& !StringUtils.isEmpty(endDate)) {
            parmaKeyDict.put(PingAnField.BEGINDATE, beginDate);
            parmaKeyDict.put(PingAnField.ENDDATE, endDate);
        }

        String pageNum = map.get(PingAnField.PAGENUM);
        String page = AssistantUtil.formatePageNum(pageNum);
        parmaKeyDict.put(PingAnField.PAGENUM, page);
        return parmaKeyDict;
    }

    /**
     *
     * 查询银行时间段内清分提现明细【6073】
     *
     * @param map 传入的数据
     * @return
     */
    public HashMap initQueryDistributionAndWithDrawDetailMap(HashMap<String, String> map) {
        HashMap parmaKeyDict = initSendMap(TranFunc.QUERY_DISTRIBUTION_AND_WITHDRAWDETAIL);
        AssociatorSubAccount accountByUserInfo = userInfoUtil.getAssociatorSubAccountByUserInfo(map);
//        if (accountByUserInfo == null) {
//            throw new IllegalArgumentException("您还未开户，请先开户");
//        }
//        parmaKeyDict.put(PingAnField.CUSTACCTID, accountByUserInfo.getSubAccountid());
        parmaKeyDict.put(PingAnField.CUSTACCTID, "3239000000006067");

        String funcFlag = map.get(PingAnField.FUNCFLAG);
        if (StringConstant.TODAY.equals(funcFlag)) {
            parmaKeyDict.put(PingAnField.FUNCFLAG, funcFlag);
        } else {
            parmaKeyDict.put(PingAnField.FUNCFLAG, StringConstant.HISTORY);
        }
        String selectFlag = map.get(PingAnField.SELECTFLAG);
        if (StringConstant.DISTRIBUTION.equals(selectFlag)
                || StringConstant.ACCOUNT_WITH_DRAW.equals(selectFlag)) {
            parmaKeyDict.put(PingAnField.SELECTFLAG, selectFlag);
        } else {
            throw new IllegalArgumentException("请指定查询类型清分或提现");
        }

        if (funcFlag.equals(StringConstant.HISTORY)) {
            String beginDate = map.get(PingAnField.BEGINDATE);
            if (StringUtils.isEmpty(beginDate)) {
                throw new IllegalArgumentException("传入的起始时间为空");
            }
            parmaKeyDict.put(PingAnField.BEGINDATE, beginDate);

            String endDate = map.get(PingAnField.ENDDATE);
            if (StringUtils.isEmpty(endDate)) {
                throw new IllegalArgumentException("传入的截止时间为空");
            }
            parmaKeyDict.put(PingAnField.ENDDATE, endDate);
        }

        String pageNum = map.get(PingAnField.PAGENUM);
        String page = AssistantUtil.formatePageNum(pageNum);
        parmaKeyDict.put(PingAnField.PAGENUM, page);
        return parmaKeyDict;
    }

    /**
     * 根据会员代码查询会员子账号【6092】
     *
     * @param map 传入的数据
     * @return
     */
    public HashMap initQueryAccountInfoMap(HashMap<String, String> map) {
        HashMap parmaKeyDict = initSendMap(TranFunc.QUERY_ACCOUNT_INFO);
        AssociatorSubAccount accountByUserInfo = userInfoUtil.getAssociatorSubAccountByUserInfo(map);
//        if (accountByUserInfo == null) {
//            throw new IllegalArgumentException("您还未开户，请先开户");
//        }
//        parmaKeyDict.put(PingAnField.THIRDHTID, accountByUserInfo.getPingAnThirdId());
        parmaKeyDict.put(PingAnField.THIRDCUSTID, "10000017781004345710");
        return parmaKeyDict;
    }

    /**
     * 查询对账文件信息【6103】（余额，充值，体现，交易）
     *
     * @param map 传入的数据
     * @return
     */
    public HashMap initQueryAccountStatementMap(HashMap<String, String> map) {
        HashMap parmaKeyDict = initSendMap(TranFunc.QUERY_ACCOUNTSTATEMENT);
        String tranDate = map.get(PingAnField.TRANDATE);
        if (StringUtils.isEmpty(tranDate)) {
            throw new IllegalArgumentException("传入的文件日期为空");
        }
        parmaKeyDict.put(PingAnField.TRANDATE, tranDate);
        String fileType = map.get(PingAnField.FILETYPE);

        if (StringConstant.RECHARGE_FILETYPE.equals(fileType) || StringConstant.TRADE_FILETYPE.equals(fileType)
                || StringConstant.WITHDRAW_FILETYPE.equals(fileType) || StringConstant.REMAINDER_FILETYPE.equals(fileType)) {
            parmaKeyDict.put(PingAnField.FILETYPE, fileType);
        } else {
            throw new IllegalArgumentException("您需要下载文件不存在");
        }
        return parmaKeyDict;
    }


    /**
     * 初始化 查询银行子账户余额 信息 【6010】
     *
     * @param map 传入的信息
     * @return
     */
    public HashMap initQuerySubAccountRemainderMap(HashMap<String, String> map) {
        HashMap hashMap = initSendMap(TranFunc.QUERY_SUBACCOUNT_REMAINDER);
        String selectFlag = map.get(PingAnField.SELECTFLAG);
        if (StringConstant.QUERY_ACCOUNT_REMAINDER_NORMAL.equals(selectFlag) ||
                StringConstant.QUERY_ACCOUNT_REMAINDER_FEATURE.equals(selectFlag)) {
            hashMap.put(PingAnField.SELECTFLAG, selectFlag);
        } else {
            throw new IllegalArgumentException("传入的查询账户类型不正确");
        }
       /* AssociatorSubAccount accountByUserInfo = userInfoUtil.getAssociatorSubAccountByUserInfo(map);
        if (accountByUserInfo == null) {
            throw new IllegalArgumentException("您还未开户，请先开户");
        }
        hashMap.put(PingAnField.CUSTACCTID, accountByUserInfo.getSubAccountid());*/


        hashMap.put(PingAnField.CUSTACCTID, map.get(PingAnField.CUSTACCTID));
        String pageNum = map.get(PingAnField.PAGENUM);
        if (StringUtils.isEmpty(pageNum)) {
            pageNum = StringConstant.ZERO_STRING;
        } else {
            try {
                Integer integer = Integer.valueOf(pageNum);
            } catch (NumberFormatException e) {
                pageNum = StringConstant.ZERO_STRING;
            }
        }
        hashMap.put(PingAnField.PAGENUM, pageNum);
        return hashMap;
    }

    /**
     * 初始化银行订单交易状态查询
     *
     * @param map  传入的数据
     * @return
     */
    public HashMap initOrderTradeStatusMap(HashMap<String, String> map) {
        HashMap hashMap = initSendMap(TranFunc.ORDER_TRADE_STATUS);
        String funcFlag = map.get(PingAnField.FUNCFLAG);
        if (StringConstant.WITH_DRAW.equals(funcFlag) ||
                StringConstant.RECHARGE.equals(funcFlag)) {
            hashMap.put(PingAnField.FUNCFLAG, funcFlag);
        } else {
            hashMap.put(PingAnField.FUNCFLAG, StringConstant.MEMBER_TRADE);
        }
      /*  AssociatorSubAccount accountByUserInfo = userInfoUtil.getAssociatorSubAccountByUserInfo(map);
        if (accountByUserInfo == null) {
            throw new IllegalArgumentException("您还未开户，请先开户");
        }
        hashMap.put(PingAnField.CUSTACCTID, accountByUserInfo.getSubAccountid());*/
        hashMap.put(PingAnField.CUSTACCTID, map.get(PingAnField.CUSTACCTID));
        String origThirdLogNo = map.get(PingAnField.ORIGTHIRDLOGNO);
        if (StringUtils.isEmpty(origThirdLogNo)) {
            throw new IllegalArgumentException("传入的流水号为空");
        } else {
            hashMap.put(PingAnField.ORIGTHIRDLOGNO, origThirdLogNo);
        }

        String tranDate = map.get(PingAnField.TRANDATE);
        /*if (StringUtils.isEmpty(tranDate)) {
            throw new IllegalArgumentException("传入的交易时间为空");
        } else {
            hashMap.put(PingAnField.TRANDATE, tranDate);
        }*/
        return hashMap;
    }

    /**
     * 初始化银行提现退单的map
     *
     * @param map  传入的数据
     * @return
     */
    public HashMap initQueryWithdrawChargeBackMap(HashMap<String, String> map) {
        HashMap hashMap = initSendMap(TranFunc.QUERY_WITHDRAW_CHARGEBACK);
        hashMap.put(PingAnField.FUNCFLAG, StringConstant.MIN_POSITIVE_INTEGER);

        String beginDate = map.get(PingAnField.BEGINDATE);
        if (StringUtils.isEmpty(beginDate)) {
            throw new IllegalArgumentException("传入的开始时间为空");
        }
        hashMap.put(PingAnField.BEGINDATE, beginDate);

        String endDate = map.get(PingAnField.ENDDATE);
        if (StringUtils.isEmpty(endDate)) {
            throw new IllegalArgumentException("传入的结算日期为空");
        }

        hashMap.put(PingAnField.ENDDATE, endDate);

        return hashMap;
    }


    /**
     * 初始化查询普通转账充值明细 的map
     *
     * @param map  传入的数据
     * @return
     */
    public HashMap initQueryTransferAccountsDetailMap(HashMap<String, String> map) {
        HashMap hashMap = initSendMap(TranFunc.QUERY_TRANSFERACCOUNTS_DETAIL);
        hashMap.put(PingAnField.FUNCFLAG, StringConstant.MIN_POSITIVE_INTEGER);

        String beginDate = map.get(PingAnField.BEGINDATE);
        if (StringUtils.isEmpty(beginDate)) {
            throw new IllegalArgumentException("传入的开始时间为空");
        }
        hashMap.put(PingAnField.BEGINDATE, beginDate);

        String endDate = map.get(PingAnField.ENDDATE);
        if (StringUtils.isEmpty(endDate)) {
            throw new IllegalArgumentException("传入的结算日期为空");
        }

        hashMap.put(PingAnField.ENDDATE, endDate);

        String pageNum = map.get(PingAnField.PAGENUM);
        String page = AssistantUtil.formatePageNum(pageNum);
        hashMap.put(PingAnField.PAGENUM, page);

        hashMap.put(PingAnField.CUSTACCTID, map.get(PingAnField.CUSTACCTID));

        return hashMap;
    }

    /**
     * 初始化 查询子账户交易的信息 的map
     *
     * @param map  传入的数据
     * @return
     */
    public HashMap initQueryAccountTradeInfoMap(HashMap<String, String> map) {
        HashMap hashMap = initSendMap(TranFunc.QUERY_ACCOUNTTRADEINFO);

        String funcFlag = map.get(PingAnField.FUNCFLAG);
        if (StringUtils.isEmpty(funcFlag) || !StringConstant.HISTORY.equals(funcFlag)) {
            funcFlag = StringConstant.TODAY;
        } else {
            funcFlag = StringConstant.HISTORY;
        }
        hashMap.put(PingAnField.FUNCFLAG, funcFlag);

       /* AssociatorSubAccount userInfo = userInfoUtil.getAssociatorSubAccountByUserInfo(map);
        if (userInfo == null) {
            throw new IllegalArgumentException("请先开通账户");
        }
        hashMap.put(PingAnField.CUSTACCTID, userInfo.getSubAccountid());*/
        hashMap.put(PingAnField.CUSTACCTID, map.get(PingAnField.CUSTACCTID));
        String selectFlag = map.get(PingAnField.SELECTFLAG);
        if (StringConstant.TRANSFER_OUT.equals(selectFlag) ||
                StringConstant.TRANSFER_IN.equals(selectFlag)) {
            hashMap.put(PingAnField.SELECTFLAG, selectFlag);
        } else {
            hashMap.put(PingAnField.SELECTFLAG, StringConstant.TRANSFER_ALL);
        }

        if (funcFlag.equals(StringConstant.HISTORY)) {
            String beginDate = map.get(PingAnField.BEGINDATE);
            if (StringUtils.isEmpty(beginDate)) {
                throw new IllegalArgumentException("传入的开始时间为空");
            }
            hashMap.put(PingAnField.BEGINDATE, beginDate);

            String endDate = map.get(PingAnField.ENDDATE);
            if (StringUtils.isEmpty(endDate)) {
                throw new IllegalArgumentException("传入的结算日期为空");
            }

            hashMap.put(PingAnField.ENDDATE, endDate);
        }

        String pageNum = map.get(PingAnField.PAGENUM);
        String page = AssistantUtil.formatePageNum(pageNum);
        hashMap.put(PingAnField.PAGENUM, page);

        return hashMap;
    }

    /**
     * 初始化充值的信息
     * @return
     */
    public HashMap initDistributionSpecialAccountMap(HashMap<String, String> map) {
        HashMap hashMap = initSendMap(TranFunc.DISTRIBUTION_SPECIAL_ACCOUNT);
      /*  AssociatorSubAccount userInfo = userInfoUtil.getAssociatorSubAccountByUserInfo(map);
        if (userInfo == null) {
            throw new IllegalArgumentException("传入的账户不存在");
        }*/
        /*hashMap.put(PingAnField.CUSTACCTID, userInfo.getSubAccountid());
        hashMap.put(PingAnField.THIRDHTID, userInfo.getPingAnThirdId());
        hashMap.put(PingAnField.CUSTNAME, userInfo.getNickName());*/

        hashMap.put(PingAnField.CUSTACCTID, map.get(PingAnField.CUSTACCTID));
        hashMap.put(PingAnField.THIRDHTID, map.get(PingAnField.THIRDHTID));
        hashMap.put(PingAnField.CUSTNAME, map.get(PingAnField.CUSTNAME));
        String tranAmout = map.get(PingAnField.TRANAMOUNT);
        if (StringUtils.isEmpty(tranAmout)) {
            throw new IllegalArgumentException("传入的金额为空");
        } else {
            try {
                Double aDouble = Double.valueOf(tranAmout);
            } catch (NumberFormatException e) {
                throw new IllegalArgumentException("输入的金额不是数字");
            }
            hashMap.put(PingAnField.TRANAMOUNT, NumberUtil.fractionNumHalfUp(tranAmout, IntegerConstant.FRACTION));
        }
        hashMap.put(PingAnField.CCYCODE, StringConstant.RMB_CURRENCY);
        String useruu = map.get(B2CField.USERUU);
        if (StringUtils.isEmpty(useruu)) {
            throw new IllegalArgumentException("传入的个人信息为空");
        }

        String frontLogNo = map.get(PingAnField.FRONTLOGNO);
        if (StringUtils.isEmpty(frontLogNo)) {
            throw new IllegalArgumentException("传入的前置流水号为空");
        }
        hashMap.put(PingAnField.FRONTLOGNO, frontLogNo);
        return hashMap;
    }

    /**
     * 初始化 查询充值明细接口
     * @return
     */
    public HashMap<String, String> initQueryRechargeDetailMap(HashMap<String, String> map) {
        HashMap<String, String> hashMap = initSendMap(TranFunc.RECHARGE_DETAIL);
        hashMap.put(PingAnField.ACQCHANNELTYPE, StringConstant.CROSS_BANK_RECEIVABLES_DELAY);

        String orderId = map.get(KHField.ORDERID);
        if (StringUtils.isEmpty(orderId)) {
            throw new IllegalArgumentException("传入的订单号为空");
        }
        hashMap.put(PingAnField.THIRDHTID, orderId);

        return hashMap;
    }

    /**
     * 初始化调账的接口
     *
     * @param map
     * @return
     */
    public HashMap initAdjustAccountMap(HashMap<String, String> map) {
        HashMap hashMap = initSendMap(TranFunc.ADJUST_ACCOUNT);
        String acqChannelType = map.get(PingAnField.ACQCHANNELTYPE);
        if (StringUtils.isEmpty(acqChannelType)) {
            throw new IllegalArgumentException("传入的收单渠道为空");
        } else if (StringConstant.CHENGE_GATHERING.equals(acqChannelType)
                || StringConstant.CROSS_BANK_RECEIVABLES_DELAY.equals(acqChannelType) || StringConstant.CROSS_BANK_RECEIVABLES__REAL_TIME.equals(acqChannelType)) {
            hashMap.put(PingAnField.ACQCHANNELTYPE, acqChannelType);
        } else {
            throw new IllegalArgumentException("传入的收单渠道不正确");
        }

        String thirdHTid = map.get(PingAnField.THIRDHTID);
        if (StringUtils.isEmpty(thirdHTid)) {
            throw new IllegalArgumentException("传入的订单号为空");
        }
        hashMap.put(PingAnField.THIRDHTID, thirdHTid);

        AssociatorSubAccount userInfo = userInfoUtil.getAssociatorSubAccountByUserInfo(map);
        if (userInfo == null) {
            throw new IllegalArgumentException("该账户还未开通");
        }
        hashMap.put(PingAnField.CUSTACCTID, userInfo.getSubAccountid());
        hashMap.put(PingAnField.THIRDCUSTID, userInfo.getPingAnThirdId());
        //TODO 传入的子账户名
        String custName = map.get(PingAnField.CUSTNAME);
        if (StringUtils.isEmpty(custName)) {
            throw new IllegalArgumentException("传入的子账户名称为空");
        } else {
            hashMap.put(PingAnField.CUSTNAME, custName);
        }

        String tranAmout = map.get(PingAnField.TRANAMOUNT);

        try {
            Double.valueOf(tranAmout);
        } catch (Exception e) {
            throw new IllegalArgumentException("传入的金额不正确");
        }
        Double amout = NumberUtil.fractionNumHalfUp(tranAmout, IntegerConstant.FRACTION);
        hashMap.put(PingAnField.TRANAMOUNT, amout);

        hashMap.put(PingAnField.CCYCODE, StringConstant.RMB_CURRENCY);
        return hashMap;
    }

    /**
     * 初始化  平台补账(见证+收单)【6147】 接口
     *
     * @param map
     * @return
     */
    public HashMap initMakeUpAccountMap(HashMap<String, String> map) {
        HashMap hashMap = initSendMap(TranFunc.MAKE_UP_ACCOUNT);
        String acqChannelType = map.get(PingAnField.ACQCHANNELTYPE);
        if (StringUtils.isEmpty(acqChannelType)) {
            throw new IllegalArgumentException("传入的收单渠道为空");
        } else if (StringConstant.CHENGE_GATHERING.equals(acqChannelType)
                || StringConstant.CROSS_BANK_RECEIVABLES_DELAY.equals(acqChannelType) || StringConstant.CROSS_BANK_RECEIVABLES__REAL_TIME.equals(acqChannelType)) {
            hashMap.put(PingAnField.ACQCHANNELTYPE, acqChannelType);
        } else {
            throw new IllegalArgumentException("传入的收单渠道不正确");
        }

        String thirdHTid = map.get(PingAnField.THIRDHTID);
        if (StringUtils.isEmpty(thirdHTid)) {
            throw new IllegalArgumentException("传入的订单号为空");
        }
        hashMap.put(PingAnField.THIRDHTID, thirdHTid);

        String tranAmout = map.get(PingAnField.TRANAMOUNT);
        try {
            Double.valueOf(tranAmout);
        } catch (Exception e) {
            throw new IllegalArgumentException("传入的金额不正确");
        }
        Double amout = NumberUtil.fractionNumHalfUp(tranAmout, IntegerConstant.FRACTION);
        hashMap.put(PingAnField.TRANAMOUNT, amout);
        return hashMap;
    }


//    /**
//     * 初始化充值的信息
//     * @return
//     */
//    public HashMap initRechargeAccount(HashMap map) {
//        HashMap hashMap = initSendMap();
//        hashMap.put(PingAnField.TRANFUNC, TranFunc.RECHARGE_ACCOUNT);
//        hashMap.put(PingAnField.CUSTACCTID, map.get(PingAnField.CUSTACCTID));
//        hashMap.put(PingAnField.THIRDHTID, map.get(PingAnField.THIRDHTID));
//        hashMap.put(PingAnField.TRANAMOUNT, map.get(PingAnField.TRANAMOUNT));
//        String thirdLogNo = AssistantUtil.getThirdLogNo((Long) map.get(B2CField.USERUU));
//        hashMap.put(PingAnField.THIRDLOGNO, thirdLogNo);
//        hashMap.put(PingAnField.CCYCODE, PingAnProperties.CURRENCYTYPE);
//        return hashMap;
//    }

    /**
     * 生成发送的map的信息
     * @param map
     * @return
     */
    public ResultMap initOpenSubAccountMap(HashMap<String, String> map) {
        //用于存放生成向银行请求报文的参数
        HashMap<String, String> parmaKeyDict = initSendMap(TranFunc.OPEN_SUB_ACCOUNT);
        // 第一部分：生成发送银行的请求的报文的实例
        String pingAnThirdId = AssistantUtil.getThirdAssociatorID(map);
        parmaKeyDict.put(PingAnField.THIRDCUSTID, pingAnThirdId);

        /*报文体*/
        parmaKeyDict.put(PingAnField.FUNCFLAG, PingAnProperties.OPEN_ACCOUNT); //功能标志1：开户
        String custProperty = map.get(PingAnField.CUSTPROPERTY);
        if (PingAnProperties.NORMALCUSTPROPERTY.equals(custProperty) || PingAnProperties.COMMERCIALCUSTPROPERTY.equals(custProperty)) {
            parmaKeyDict.put(PingAnField.CUSTPROPERTY, custProperty); //会员属性
        } else {
            return new ResultMap(CodeType.failure, "传入的子账户属性为空", null);
        }
        parmaKeyDict.put(PingAnField.NICKNAME, StringUtil.getString(map.get(PingAnField.NICKNAME)));
        parmaKeyDict.put(PingAnField.MOBILEPHONE, StringUtil.getString(map.get(PingAnField.MOBILEPHONE)));
        parmaKeyDict.put(PingAnField.EMAIL, StringUtil.getString(map.get(PingAnField.EMAIL)));
        String reserve = map.get(PingAnField.RESERVE) == null ? StringConstant.EMPTY_STR : StringUtil.getString(map.get(PingAnField.RESERVE));
        parmaKeyDict.put(PingAnField.RESERVE, reserve);
        return new ResultMap(CodeType.success, "成功", parmaKeyDict);
    }


    /**
     * 初始化绑定提现账户map信息
     *
     * @return
     */
    public HashMap initUnionPaybindBankCard(HashMap map) {
        HashMap parmaKeyDict = initSendMap(TranFunc.BIND_CARD_UNIONPAY);
        //这里需要从数据库获取AssociatorSubAccount账户，填充到这里来
        parmaKeyDict.put("CustAcctId", map.get("CustAcctId"));
        parmaKeyDict.put("ThirdCustId", map.get("ThirdCustId"));
        parmaKeyDict.put("CustName", map.get("CustName"));
        parmaKeyDict.put("IdType", map.get("IdType"));
        parmaKeyDict.put("IdCode", map.get("IdCode"));
        parmaKeyDict.put("AcctId", map.get("AcctId"));
        parmaKeyDict.put("BankType", map.get("BankType"));
        parmaKeyDict.put("BankName", map.get("BankName"));
        if (PingAnProperties.SIZE_LIN_NUMBER.equals(map.get("super_size_type"))) {
            parmaKeyDict.put("BankCode", map.get("BankCode"));
            parmaKeyDict.put("SBankCode", "");
        } else if (PingAnProperties.SUPERBANKNUM.equals(map.get("super_size_type"))) {
            //超级网银的账号
            parmaKeyDict.put("SBankCode", map.get("SBankCode"));
            parmaKeyDict.put("BankCode", "");
        } else {
            throw new IllegalArgumentException("传入的银行代号类型报错，只能选择大小额行号或超级网银号");
        }
        parmaKeyDict.put("MobilePhone", map.get("MobilePhone"));
        parmaKeyDict.put("Reserve", "");
        return parmaKeyDict;
    }


    /**
     * 初始化通过银联方式绑定提现账户 验证过程的map
     * @param map
     * @return
     */
    public HashMap<String, String> initSmsVerificationBindBankCardMap(HashMap<String, String> map) {
        HashMap parmaKeyDict = initSendMap(TranFunc.BIND_CARD_UNIONPAY_SMS_VERIFICATION);
        String useruu = map.get(B2CField.USERUU);
       /* if (StringUtils.isEmpty(useruu)) {
            throw new IllegalArgumentException("传入的个人uu信息为空");
        }*/
        //要修改的部分
      /*  AssociatorSubAccount subAccount = userInfoUtil.getAssociatorSubAccountByUserInfo(map);
        if (subAccount == null) {
            throw new IllegalArgumentException("请先开通子账号");
        }
        parmaKeyDict.put(PingAnField.CUSTACCTID, subAccount.getSubAccountid());
        parmaKeyDict.put(PingAnField.THIRDCUSTID, subAccount.getSubAccountid());*/
        parmaKeyDict.put(PingAnField.CUSTACCTID, map.get(PingAnField.CUSTACCTID));
        parmaKeyDict.put(PingAnField.THIRDCUSTID, map.get(PingAnField.THIRDCUSTID));


        String acctId = map.get(PingAnField.DYNAMIC_VERIFICATION_BIND_BANK_CARD_ACCTID);
        if (StringUtils.isEmpty(acctId)) {
            throw new IllegalArgumentException("传入的会员账号为空");
        }
        parmaKeyDict.put(PingAnField.DYNAMIC_VERIFICATION_BIND_BANK_CARD_ACCTID, acctId);
        String messageCode = map.get(PingAnField.MESSAGE_CODE);
        if (StringUtils.isEmpty(messageCode)) {
            throw new IllegalArgumentException("短信验证码为空");
        }
        parmaKeyDict.put(PingAnField.MESSAGE_CODE, messageCode);
        return parmaKeyDict;
    }

    /**
     * 绑定提现账户 - 小额鉴权
     *
     * @param map 传入的数据
     * @return
     */
    public HashMap<String, String> initMoneyBindBankCardMap(HashMap<String, String> map) {
        HashMap parmaKeyDict = initSendMap(TranFunc.BIND_CARD_MONEY);
      /*  AssociatorSubAccount userInfo = userInfoUtil.getAssociatorSubAccountByUserInfo(map);
        if (userInfo == null) {
            throw new IllegalArgumentException("请先开通账号");
        }
        parmaKeyDict.put(PingAnField.CUSTACCTID, userInfo.getSubAccountid());
        parmaKeyDict.put(PingAnField.THIRDCUSTID, userInfo.getPingAnThirdId());*/


        parmaKeyDict.put(PingAnField.CUSTACCTID, map.get(PingAnField.CUSTACCTID));
        parmaKeyDict.put(PingAnField.THIRDCUSTID, map.get(PingAnField.THIRDCUSTID));
        String custName = map.get(PingAnField.CUSTNAME);
        if (StringUtils.isEmpty(custName)) {
            throw new IllegalArgumentException("传入的会员名称为空");
        }
        parmaKeyDict.put(PingAnField.CUSTNAME, custName);
        String idType = map.get(PingAnField.IDTYPE);
        if (StringUtils.isEmpty(idType)) {
            throw new IllegalArgumentException("传入的证件类型为空");
        }
        parmaKeyDict.put(PingAnField.IDTYPE, idType);
        String idCode = map.get(PingAnField.IDCODE);
        if (StringUtils.isEmpty(idCode)) {
            throw new IllegalArgumentException("传入的证件号为空");
        }
        parmaKeyDict.put(PingAnField.IDCODE, idCode);

        // TODO 这里的本行还是他行 需要 事先判断
        String bankType = map.get(PingAnField.BANKTYPE);
        if (StringUtils.isEmpty(bankType)) {
            throw new IllegalArgumentException("传入的银行类型为空");
        }
        parmaKeyDict.put(PingAnField.BANKTYPE, bankType);

        String AcctId = map.get(PingAnField.DYNAMIC_VERIFICATION_BIND_BANK_CARD_ACCTID);
        if (StringUtils.isEmpty(AcctId)) {
            throw new IllegalArgumentException("传入的会员账号为空");
        }
        parmaKeyDict.put(PingAnField.DYNAMIC_VERIFICATION_BIND_BANK_CARD_ACCTID, AcctId);

        String bankName = map.get(PingAnField.BankName);
        if (StringUtils.isEmpty(bankName)) {
            throw new IllegalArgumentException("传入的开户行名称为空");
        }
        parmaKeyDict.put(PingAnField.BankName, bankName);

        String bankCode = map.get(PingAnField.BANKCODE);
        if (StringUtils.isEmpty(bankCode)) {
            String sBankCode = map.get(PingAnField.SBANKCODE);
            parmaKeyDict.put(PingAnField.SBANKCODE, sBankCode);
        } else {
            parmaKeyDict.put(PingAnField.BANKCODE, bankCode);
        }

        String mobilePhone = map.get(PingAnField.MOBILEPHONE);
        if (StringUtils.isEmpty(mobilePhone)) {
            throw new IllegalArgumentException("传入的手机号为空");
        }
        parmaKeyDict.put(PingAnField.MOBILEPHONE, mobilePhone);
        return parmaKeyDict;
    }

    /**
     * 绑定提现账户 - 小额鉴权 验证信息
     *
     * @param map
     * @return
     */
    public HashMap<String, String> initMoneyVerificationBindBankCardMap(HashMap<String, String> map) {
        HashMap parmaKeyDict = initSendMap(TranFunc.BIND_CARD_MONEY_VERIFICATION);
       /* AssociatorSubAccount userInfo = userInfoUtil.getAssociatorSubAccountByUserInfo(map);
        if (userInfo == null) {
            throw new IllegalArgumentException("请先开通账户");
        }
        String useruu = map.get(B2CField.USERUU);
        if (StringUtils.isEmpty(useruu)) {
            throw new IllegalArgumentException("传入的用户信息为空");
        }
        parmaKeyDict.put(PingAnField.THIRDCUSTID, userInfo.getPingAnThirdId());
        parmaKeyDict.put(PingAnField.CUSTACCTID, userInfo.getSubAccountid());*/

        parmaKeyDict.put(PingAnField.CUSTACCTID, map.get(PingAnField.CUSTACCTID));
        parmaKeyDict.put(PingAnField.THIRDCUSTID, map.get(PingAnField.THIRDCUSTID));

        String acctid = map.get(PingAnField.DYNAMIC_VERIFICATION_BIND_BANK_CARD_ACCTID);
        if (StringUtils.isEmpty(acctid)) {
            throw new IllegalArgumentException("传入的提现账号为空");
        }
        parmaKeyDict.put(PingAnField.DYNAMIC_VERIFICATION_BIND_BANK_CARD_ACCTID, acctid);

        String tranAmount = map.get(PingAnField.TRANAMOUNT);
        if (StringUtils.isEmpty(tranAmount)) {
            throw new IllegalArgumentException("传入的鉴权金额为空");
        }
        parmaKeyDict.put(PingAnField.TRANAMOUNT, tranAmount);
        parmaKeyDict.put(PingAnField.CCYCODE, StringConstant.RMB_CURRENCY);
        return parmaKeyDict;
    }

    /**
     * 初始化查询绑卡信息接口
     *
     * @param map
     * @return HashMap<String, String>
     */
    public HashMap<String, String> initqueryBindInfoMap(HashMap<String, String> map) {
        HashMap parmaKeyDict = initSendMap(TranFunc.BIND_CARD_QUERY);
     /*   AssociatorSubAccount userInfo = userInfoUtil.getAssociatorSubAccountByUserInfo(map);
        if (userInfo == null) {
            throw new IllegalArgumentException("请先开通账户");
        }
        String useruu = map.get(B2CField.USERUU);
        if (StringUtils.isEmpty(useruu)) {
            throw new IllegalArgumentException("传入的用户信息为空");
        }*/
       // parmaKeyDict.put(PingAnField.CUSTACCTID, userInfo.getSubAccountid());

        parmaKeyDict.put(PingAnField.CUSTACCTID, map.get(PingAnField.CUSTACCTID));
        parmaKeyDict.put(PingAnField.SELECTFLAG, StringConstant.SELECTFLAG_SINGLE);
        String pageNum = map.get(PingAnField.PAGENUM);
        if (StringUtils.isEmpty(pageNum)) {
            pageNum = StringConstant.MIN_POSITIVE_INTEGER;
        } else {
            try {
                Integer integer = Integer.valueOf(pageNum);
            } catch (NumberFormatException e) {
                pageNum = StringConstant.MIN_POSITIVE_INTEGER;
            }
        }

        parmaKeyDict.put(PingAnField.PAGENUM, pageNum);
        return parmaKeyDict;
    }

    /**
     * 初始化解绑的map
     *
     * @param map
     * @return
     */
    public HashMap<String, String> initUnbundlingCardMap(HashMap<String, String> map) {
        HashMap parmaKeyDict = initSendMap(TranFunc.UNBUNDLING_BIND_CARD);
       /* AssociatorSubAccount userInfo = userInfoUtil.getAssociatorSubAccountByUserInfo(map);
        if (userInfo == null) {
            throw new IllegalArgumentException("请先开通账户");
        }
        String useruu = map.get(B2CField.USERUU);
        if (StringUtils.isEmpty(useruu)) {
            throw new IllegalArgumentException("传入的用户信息为空");
        }
        parmaKeyDict.put(PingAnField.CUSTACCTID, userInfo.getSubAccountid());
        parmaKeyDict.put(PingAnField.THIRDCUSTID, userInfo.getPingAnThirdId());*/

        parmaKeyDict.put(PingAnField.CUSTACCTID, map.get(PingAnField.CUSTACCTID));
        parmaKeyDict.put(PingAnField.THIRDCUSTID, map.get(PingAnField.THIRDCUSTID));
        parmaKeyDict.put(PingAnField.FUNCFLAG, StringConstant.MIN_POSITIVE_INTEGER);
        String acctid = map.get(PingAnField.DYNAMIC_VERIFICATION_BIND_BANK_CARD_ACCTID);
        if (StringUtils.isEmpty(acctid)) {
            throw new IllegalArgumentException("传入的会员账号为空");
        }
        parmaKeyDict.put(PingAnField.DYNAMIC_VERIFICATION_BIND_BANK_CARD_ACCTID, acctid);
        return parmaKeyDict;
    }


    /**
     * 初始化解绑的map
     *
     * @param map
     * @return
     */
    public HashMap<String, String> initModifyBindCardInfoMap(HashMap<String, String> map) {
        HashMap parmaKeyDict = initSendMap(TranFunc.MODIFY_BIND_CARD_INFO);
       /* AssociatorSubAccount userInfo = userInfoUtil.getAssociatorSubAccountByUserInfo(map);
        if (userInfo == null) {
            throw new IllegalArgumentException("请先开通账户");
        }
        String useruu = map.get(B2CField.USERUU);
        if (StringUtils.isEmpty(useruu)) {
            throw new IllegalArgumentException("传入的用户信息为空");
        }*/
       // parmaKeyDict.put(PingAnField.CUSTACCTID, userInfo.getSubAccountid());


        parmaKeyDict.put(PingAnField.CUSTACCTID, map.get(PingAnField.CUSTACCTID));

        String acctid = map.get(PingAnField.DYNAMIC_VERIFICATION_BIND_BANK_CARD_ACCTID);
        if (StringUtils.isEmpty(acctid)) {
            throw new IllegalArgumentException("传入的会员账号为空");
        }
        parmaKeyDict.put(PingAnField.DYNAMIC_VERIFICATION_BIND_BANK_CARD_ACCTID, acctid);

        String bankName = map.get(PingAnField.BankName);
        if (StringUtils.isEmpty(bankName)) {
            throw new IllegalArgumentException("传入的开户行名称为空");
        }
        parmaKeyDict.put(PingAnField.BankName, bankName);

        String bankCode = map.get(PingAnField.BANKCODE);
        if (StringUtils.isEmpty(bankCode)) {
            String sBankCode = map.get(PingAnField.SBANKCODE);
            if (StringUtils.isEmpty(sBankCode)) {
                throw new IllegalArgumentException("传入的超级网银号或者联行号为空");
            }
            parmaKeyDict.put(PingAnField.SBANKCODE, sBankCode);
        } else {
            parmaKeyDict.put(PingAnField.BANKCODE, bankCode);
        }
        return parmaKeyDict;
    }

    /**
     * 初始化修改手机号验证短信验证码的动作
     *
     * @param map
     * @return
     */
    public HashMap<String, String> initmodifyBindCardTelephoneMap(HashMap<String, String> map) {
        HashMap parmaKeyDict = initSendMap(TranFunc.MODIFY_BIND_CARD_TELEPHONE);
      /*  AssociatorSubAccount userInfo = userInfoUtil.getAssociatorSubAccountByUserInfo(map);
        if (userInfo == null) {
            throw new IllegalArgumentException("请先开通账户");
        }
        String useruu = map.get(B2CField.USERUU);
        if (StringUtils.isEmpty(useruu)) {
            throw new IllegalArgumentException("传入的用户信息为空");
        }*/
       /* parmaKeyDict.put(PingAnField.CUSTACCTID, userInfo.getSubAccountid());
        parmaKeyDict.put(PingAnField.THIRDCUSTID, userInfo.getPingAnThirdId());*/


        parmaKeyDict.put(PingAnField.CUSTACCTID, map.get(PingAnField.CUSTACCTID));
        parmaKeyDict.put(PingAnField.THIRDCUSTID, map.get(PingAnField.THIRDCUSTID));
        String modifyType = map.get(PingAnField.MODIFIEDTYPE);
        if (StringUtils.isEmpty(modifyType)) {
            throw new IllegalArgumentException("传入的修改方式为空");
        }
        if (StringConstant.SMS_VALIDATE.equals(modifyType)) {
            parmaKeyDict.put(PingAnField.MODIFIEDTYPE, modifyType);
        } else if (StringConstant.UNIONPAY_AUTHENTICATION.equals(modifyType)) {
            parmaKeyDict.put(PingAnField.MODIFIEDTYPE, modifyType);
            String acctid = map.get(PingAnField.DYNAMIC_VERIFICATION_BIND_BANK_CARD_ACCTID);
            if (StringUtils.isEmpty(acctid)) {
                throw new IllegalArgumentException("传入的会员账号为空");
            }
            parmaKeyDict.put(PingAnField.DYNAMIC_VERIFICATION_BIND_BANK_CARD_ACCTID, acctid);
        } else {
            throw new IllegalArgumentException("传入的修改方式不存在");
        }

        String newPhone = map.get(PingAnField.NEW_MOBILEPHONE);
        if (StringUtils.isEmpty(newPhone)) {
            throw new IllegalArgumentException("传入的手机号为空");
        }
        parmaKeyDict.put(PingAnField.NEW_MOBILEPHONE, newPhone);
        return parmaKeyDict;
    }

    /**
     * 初始化修改手机号验证短信验证码的动作
     *
     * @param map
     * @return
     */
    public HashMap<String, String> initRechargeMemberMap(HashMap<String, String> map) {
        HashMap parmaKeyDict = initSendMap(TranFunc.RECHARGE_ACCOUNT);
       // AssociatorSubAccount userInfo = userInfoUtil.getAssociatorSubAccountByUserInfo(map);
     /*   if (userInfo == null) {
            throw new IllegalArgumentException("请先开通账户");
        }*/
        String useruu = map.get(B2CField.USERUU);
        if (StringUtils.isEmpty(useruu)) {
            throw new IllegalArgumentException("传入的用户信息为空");
        }
       /* parmaKeyDict.put(PingAnField.CUSTACCTID, userInfo.getSubAccountid());
        parmaKeyDict.put(PingAnField.THIRDCUSTID, userInfo.getPingAnThirdId());*/

        parmaKeyDict.put(PingAnField.CUSTACCTID,  map.get(PingAnField.CUSTACCTID));
        parmaKeyDict.put(PingAnField.THIRDCUSTID, map.get(PingAnField.THIRDCUSTID));

        String tranAmout = map.get(PingAnField.TRANAMOUNT);
        if (StringUtils.isEmpty(tranAmout)) {
            throw new IllegalArgumentException("传入的交易金额为空");
        }
        parmaKeyDict.put(PingAnField.TRANAMOUNT, tranAmout);
        parmaKeyDict.put(PingAnField.CCYCODE, StringConstant.RMB_CURRENCY);
        parmaKeyDict.put(PingAnField.NOTE, StringUtil.getString(map.get(PingAnField.NOTE)));
        return parmaKeyDict;
    }

    /**
     * 初始化解绑的map
     *
     * @param map
     * @return
     */
    public HashMap<String, String> initModifyBindCardTelephoneVerificationMap(HashMap<String, String> map) {
        HashMap parmaKeyDict = initSendMap(TranFunc.MODIFY_BIND_CARD_TELEPHONE_VERIFICATION);
       /* AssociatorSubAccount userInfo = userInfoUtil.getAssociatorSubAccountByUserInfo(map);
        if (userInfo == null) {
            throw new IllegalArgumentException("请先开通账户");
        }
        String useruu = map.get(B2CField.USERUU);
        if (StringUtils.isEmpty(useruu)) {
            throw new IllegalArgumentException("传入的用户信息为空");
        }
        parmaKeyDict.put(PingAnField.CUSTACCTID, userInfo.getSubAccountid());
        parmaKeyDict.put(PingAnField.THIRDCUSTID, userInfo.getPingAnThirdId());*/



        parmaKeyDict.put(PingAnField.CUSTACCTID,  map.get(PingAnField.CUSTACCTID));
        parmaKeyDict.put(PingAnField.THIRDCUSTID, map.get(PingAnField.THIRDCUSTID));
        String modifyType = map.get(PingAnField.MODIFIEDTYPE);
        if (StringUtils.isEmpty(modifyType)) {
            throw new IllegalArgumentException("传入的修改方式为空");
        }
        if (StringConstant.SMS_VALIDATE.equals(modifyType) || StringConstant.UNIONPAY_AUTHENTICATION.equals(modifyType)) {
            parmaKeyDict.put(PingAnField.MODIFIEDTYPE, modifyType);
        } else {
            throw new IllegalArgumentException("传入的修改方式不存在");
        }
        String serialNo = map.get(PingAnField.SERIALNO);
        if (StringUtils.isEmpty(serialNo)) {
            throw new IllegalArgumentException("传入的短信指令为空");
        }
        parmaKeyDict.put(PingAnField.SERIALNO, serialNo);

        String messageCode = map.get(PingAnField.MESSAGE_CODE);
        if (StringUtils.isEmpty(messageCode)) {
            throw new IllegalArgumentException("传入的短信验证码为空");
        }
        parmaKeyDict.put(PingAnField.MESSAGE_CODE, messageCode);
        return parmaKeyDict;
    }

    /**
     * 初始化查询小额鉴权转账的结果
     *
     * @param map
     * @return
     */
    public HashMap<String, String> initQueryMoneyBindCardResultMap(HashMap<String, String> map) {
        HashMap parmaKeyDict = initSendMap(TranFunc.QUERY_MONEY_BINDCARD_RESULT);
      /*  String useruu = map.get(B2CField.USERUU);
        if (StringUtils.isEmpty(useruu)) {
            throw new IllegalArgumentException("传入的用户信息为空");
        }*/

        String origThirdLogNo = map.get(PingAnField.ORIGTHIRDLOGNO);
        if (StringUtils.isEmpty(origThirdLogNo)) {
            throw new IllegalArgumentException("需要查询的流水号为空");
        }
        parmaKeyDict.put(PingAnField.ORIGTHIRDLOGNO, origThirdLogNo);

        String tranDate = map.get(PingAnField.TRANDATE);
        if (StringUtils.isEmpty(tranDate)) {
            throw new IllegalArgumentException("交易日期为空");
        }
        parmaKeyDict.put(PingAnField.TRANDATE, tranDate);
        return parmaKeyDict;
    }

    /**
     * 初始化获取资金汇总账户的信息的map
     * @return
     */
    public HashMap initGetBaseAccount() {
        HashMap hashMap = initSendMap(TranFunc.INQUIRY_BASE_ACCOUNT);
        hashMap.put(PingAnField.RESERVE, StringConstant.EMPTY_STR);
        return hashMap;
    }

    /**
     * 获取 子账户的信息
     * @return HashMap
     */
    public HashMap initGetSubAccountInfo(HashMap map) {
        if (MapUtils.isEmpty(map)) {
            throw new IllegalArgumentException("传入的信息为空");
        }
        HashMap<String, String> hashMap = initSendMap(TranFunc.INQUIRY_SUB_ACCOUNT);

        Object useruu = map.get(B2CField.USERUU);
        if (useruu == null) {
            throw new IllegalArgumentException("传入的个人的useruu信息为空");
        }

        String custacctid = String.valueOf(map.get(PingAnField.CUSTACCTID));
        if (StringUtils.isEmpty(custacctid)) {
            throw new IllegalArgumentException("传入的客户信息为空");
        }
        hashMap.put(PingAnField.CUSTACCTID, "3239000000006067");

        String selectFlag = String.valueOf(map.get(PingAnField.SELECTFLAG));
        if (StringUtils.isEmpty(selectFlag)) {
            throw new IllegalArgumentException("传入的查询标志（功能型账户/普通型账户）为空");
        } else {
           Boolean legal = selectFlag.equals(PingAnEnum.SELECT_FLAG_COMMON.getTag())
                    || selectFlag.equals(PingAnEnum.SELECT_FLAG_FUNCTION.getTag());
            if (!legal) {
                selectFlag = PingAnEnum.SELECT_FLAG_COMMON.getTag();
            }
        }
        hashMap.put(PingAnField.SELECTFLAG, selectFlag);

        Object num = map.get(PingAnField.PAGENUM);
        String page = getLegalPage(num);
        hashMap.put(PingAnField.PAGENUM, page);

        String reserve = String.valueOf(map.get(PingAnField.RESERVE));
        reserve = reserve == null ? StringConstant.EMPTY_STR : reserve;
        map.put(PingAnField.RESERVE, reserve);
        return hashMap;
    }

    /**
     * 获取正确的页数系信息
     *
     * @param num 传入的页数
     * @return 返回页数
     */
    public String getLegalPage(Object num) {
        String page = null;
        if (num == null) {
            page = StringConstant.MIN_POSITIVE_INTEGER;
        } else {
            page = num.toString();
        }
        try {
            Integer valueOf = Integer.valueOf(page);
            if (valueOf < 1) {
                page = StringConstant.MIN_POSITIVE_INTEGER;
            }
        } catch (Exception e) {
            page = StringConstant.MIN_POSITIVE_INTEGER;
        }
        return page;
    }


    /**
     * 初始化 查询充值明细接口
     * @return
     */
    public ResultMap khPayMap(HashMap<String, String> map) {
        HashMap<String, String> initMap = new HashMap<>();
        initMap.put(KHField.CURRENCY, StringConstant.RMB_CURRENCY);
        if (MapUtils.isEmpty(map)) {
            return new ResultMap(CodeType.failure, "支付信息为空", null);
        }
        if (StringUtils.isEmpty(map.get(KHField.ORDERID))) {
            return new ResultMap(CodeType.failure, "流水号为空", null);
        } else {
            initMap.put(KHField.ORDERID, map.get(KHField.ORDERID));
        }

        String amout = map.get(KHField.AMOUNT);
        if (StringUtils.isEmpty(amout)) {
            return new ResultMap(CodeType.failure, "金额为空", null);
        } else {
            initMap.put(KHField.AMOUNT, amout);
        }

        String objectName = map.get(KHField.OBJECTNAME);
        initMap.put(KHField.OBJECTNAME, StringUtils.isEmpty(objectName) ? StringConstant.EMPTY_STR : objectName);

        String payDate = map.get(KHField.PAYDATE);
        if (StringUtils.isEmpty(payDate)) {
            return new ResultMap(CodeType.failure, "单时间为空", null);
        } else {
            initMap.put(KHField.PAYDATE, payDate);
        }

        String verifyCode = map.get(KHField.VERIFYCODE);
        if (StringUtils.isEmpty(verifyCode)) {
            return new ResultMap(CodeType.failure, "验证码为空", null);
        } else {
            initMap.put(KHField.VERIFYCODE, verifyCode);
        }

        String openId = map.get(KHField.OPENID);
        if (StringUtils.isEmpty(openId)) {
            return new ResultMap(CodeType.failure, "开户银行号唯一标识为空", null);
        } else {
            initMap.put(KHField.OPENID, openId);
        }

        String issinscode = map.get(KHField.ISSINSCODE);
        if (StringUtils.isEmpty(issinscode)) {
            return new ResultMap(CodeType.failure, "发卡机构代码为空", null);
        } else {
            initMap.put(KHField.ISSINSCODE, issinscode);
        }

        String payCardType = map.get(KHField.PAYCARDTYPE);
        if (StringUtils.isEmpty(payCardType)) {
            return new ResultMap(CodeType.failure, "支付卡类型为空", null);
        } else {
            initMap.put(KHField.PAYCARDTYPE, payCardType);
        }

        initMap.put(KHField.MASTERID, sysconf.getMasterId());
        initMap.put(KHField.VALIDTIME, StringConstant.ZERO_STRING);
        initMap.put(KHField.PAYTYPE, PayTypeEnum.UNION_PAY.getValue());
        initMap.put(KHField.NOTIFYURL, sysconf.getHkPayNotifyUrl());

        AssociatorSubAccount associatorSubAccount = userInfoUtil.getAssociatorSubAccountByUserInfo(map);
        if (associatorSubAccount == null) {
            return new ResultMap(CodeType.failure, "找不到对应的会员信息", null);
        }
        String subAccountid = associatorSubAccount.getSubAccountid();
        initMap.put(KHField.CUSTOMERID, subAccountid);
        String remark = AssistantUtil.produceRemark(sysconf.getBusinessCode(), StringConstant.ZERO_STRING, StringConstant.MIN_POSITIVE_INTEGER, subAccountid);
        initMap.put(KHField.REMARK, remark);
        return new ResultMap(CodeType.success, "成功", initMap);
    }


    /**
     * 微信支付的接口
     *
     * @param map
     * @return
     */
    public ResultMap  initWeChatPaymentMap(HashMap<String,String> map) {
        HashMap<String, String> hashMap = new HashMap<>();
        if (MapUtils.isEmpty(map)) {
            throw new IllegalArgumentException("传入的数据为空");
        }
        hashMap.put(KHField.MASTERID, sysconf.getMasterId());
        String orderId = KHUtil.getOrderId(sysconf.getMasterId());
        hashMap.put(KHField.ORDERID, orderId);

        String amount = map.get(KHField.AMOUNT);
        if (StringUtils.isEmpty(amount)) {
            return new ResultMap(CodeType.failure, "传入的总金额为空", null);
        } else {
            hashMap.put(KHField.AMOUNT, String.valueOf(NumberUtil.fractionNumHalfUp(amount, IntegerConstant.FRACTION)));
        }

        String payTime = map.get(KHField.PAYDATE);
        if (StringUtils.isEmpty(payTime)) {
            return new ResultMap(CodeType.failure, "传入的支付时间为空", null);
        } else {
            hashMap.put(KHField.PAYDATE, payTime);
        }
        hashMap.put(KHField.VALIDTIME, StringConstant.ZERO_STRING);
        hashMap.put(KHField.NOTIFYURL, sysconf.getWeChatNotifyUrl());
        hashMap.put(KHField.PAYTYPE, PayTypeEnum.WECHAT_PAY.getValue());
        hashMap.put(KHField.CURRENCY, StringConstant.RMB_CURRENCY);
        hashMap.put(KHField.OBJECTNAME, StringUtil.getString(map.get(KHField.OBJECTNAME)));

        AssociatorSubAccount associatorSubAccount = userInfoUtil.getAssociatorSubAccountByUserInfo(map);
        if (associatorSubAccount == null) {
            return new ResultMap(CodeType.failure, "找不到对应的会员信息", null);
        }
        String subAccountid = associatorSubAccount.getSubAccountid();
        hashMap.put(KHField.CUSTOMERID, subAccountid);
        String remark = AssistantUtil.produceRemark(sysconf.getBusinessCode(), StringConstant.ZERO_STRING, StringConstant.MIN_POSITIVE_INTEGER, subAccountid);
        hashMap.put(KHField.REMARK, remark);

        return new ResultMap(CodeType.success, "成功", hashMap);
    }
}
