package com.uas.b2c.pay.util;

import com.uas.b2c.pay.constant.PingAnField;
import com.uas.b2c.pay.domain.PinganPayLog;
import com.uas.b2c.pay.properties.SysConf;
import com.uas.b2c.pay.repository.PinganPayLogRepository;
import net.sf.json.JSONObject;
import org.apache.commons.collections.MapUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.scheduling.annotation.Async;
import org.springframework.stereotype.Component;
import org.springframework.util.StringUtils;

import java.util.Date;
import java.util.HashMap;

/**
 * 发送的辅助方法
 * @author yuj 2017-12-19 18:23
 */
@Component
public class PingAnSendMessageUtil {

    private final PingAnTransfer pingAnTransfer;

    private final SysConf sysConf;

    @Autowired
    private PinganPayLogRepository pinganPayLogRepository;

    @Autowired
    public PingAnSendMessageUtil(PingAnTransfer pingAnTransfer, SysConf sysConf) {
        this.pingAnTransfer = pingAnTransfer;
        this.sysConf = sysConf;
    }

    /**
     * 向平安系统发送鉴证宝信息
     * @return
     */
    public HashMap sendMessage(HashMap<String,String> parmaKeyDict) {
        if (MapUtils.isEmpty(parmaKeyDict)) {
            return null;
        }

        //用于存放银行发送报文的参数
        HashMap retKeyDict = new HashMap();

        //调用函数生成报文
        String tranMessage = pingAnTransfer.getTranMessage(parmaKeyDict);
        //发送请求报文
        pingAnTransfer.SendTranMessage(tranMessage, sysConf.getB2biUrl(), sysConf.getServerPort(), retKeyDict);
        pinganLogSave(parmaKeyDict, retKeyDict, tranMessage);
        return retKeyDict;
    }

    /**
     * 保存请求参数和应答参数;
     * @param parmaKeyDict
     * @param retKeyDict
     * @param tranMessage
     */
    @Async
    public void pinganLogSave(HashMap parmaKeyDict, HashMap retKeyDict, String tranMessage) {
        //请求日志存储到数据库中;
        PinganPayLog pinganPayLog = new PinganPayLog();
        pinganPayLog.setServType(1);
        pinganPayLog.setTranFunc((String) parmaKeyDict.get(PingAnField.TRANFUNC));
        pinganPayLog.setRequestNo((String)parmaKeyDict.get(PingAnField.THIRDLOGNO));
        pinganPayLog.setMemberId((String)parmaKeyDict.get(PingAnField.THIRDCUSTID));
        pinganPayLog.setUserRequestData(JSONObject.fromObject(parmaKeyDict).toString());
        pinganPayLog.setPinganRequestData(tranMessage);
        pinganPayLog.setRepdata((String)retKeyDict.get(PingAnField.RECEVEMESSAGE));
        pinganPayLog.setCreateDate(new Date());
        pinganPayLogRepository.save(pinganPayLog);
    }

    /**
     * 解析银行的返回信息
     *
     * @param parseMap 银行返回的信息
     * @return
     */
    public HashMap parsingReturnMessage(HashMap parseMap) {
        if (MapUtils.isEmpty(parseMap)) {
            throw new IllegalArgumentException("传入的参数信息为空");
        }
        String responseStr = (String) parseMap.get(PingAnField.RECEVEMESSAGE);
        if (StringUtils.isEmpty(responseStr)) {
            throw new IllegalArgumentException("获取的银行返回信息为空");
        }
        HashMap resultMap = pingAnTransfer.parsingTranMessageString(responseStr);
        return resultMap;
    }

}
